import type { RouteRequestBody, RouteResponse } from '@seamapi/types/connect';
import { type Client } from '../../../../lib/seam/connect/client.js';
import { type SeamHttpFromPublishableKeyOptions, type SeamHttpOptions, type SeamHttpOptionsWithApiKey, type SeamHttpOptionsWithClient, type SeamHttpOptionsWithClientSessionToken, type SeamHttpOptionsWithConsoleSessionToken, type SeamHttpOptionsWithPersonalAccessToken, type SeamHttpRequestOptions } from '../../../../lib/seam/connect/options.js';
import { SeamHttpRequest } from '../../../../lib/seam/connect/seam-http-request.js';
import type { SetNonNullable } from '../../../../lib/types.js';
import { SeamHttpDevicesSimulate } from './devices-simulate.js';
import { SeamHttpDevicesUnmanaged } from './devices-unmanaged.js';
export declare class SeamHttpDevices {
    client: Client;
    readonly defaults: Required<SeamHttpRequestOptions>;
    constructor(apiKeyOrOptions?: string | SeamHttpOptions);
    static fromClient(client: SeamHttpOptionsWithClient['client'], options?: Omit<SeamHttpOptionsWithClient, 'client'>): SeamHttpDevices;
    static fromApiKey(apiKey: SeamHttpOptionsWithApiKey['apiKey'], options?: Omit<SeamHttpOptionsWithApiKey, 'apiKey'>): SeamHttpDevices;
    static fromClientSessionToken(clientSessionToken: SeamHttpOptionsWithClientSessionToken['clientSessionToken'], options?: Omit<SeamHttpOptionsWithClientSessionToken, 'clientSessionToken'>): SeamHttpDevices;
    static fromPublishableKey(publishableKey: string, userIdentifierKey: string, options?: SeamHttpFromPublishableKeyOptions): Promise<SeamHttpDevices>;
    static fromConsoleSessionToken(consoleSessionToken: SeamHttpOptionsWithConsoleSessionToken['consoleSessionToken'], workspaceId: SeamHttpOptionsWithConsoleSessionToken['workspaceId'], options?: Omit<SeamHttpOptionsWithConsoleSessionToken, 'consoleSessionToken' | 'workspaceId'>): SeamHttpDevices;
    static fromPersonalAccessToken(personalAccessToken: SeamHttpOptionsWithPersonalAccessToken['personalAccessToken'], workspaceId: SeamHttpOptionsWithPersonalAccessToken['workspaceId'], options?: Omit<SeamHttpOptionsWithPersonalAccessToken, 'personalAccessToken' | 'workspaceId'>): SeamHttpDevices;
    updateClientSessionToken(clientSessionToken: SeamHttpOptionsWithClientSessionToken['clientSessionToken']): Promise<void>;
    get unmanaged(): SeamHttpDevicesUnmanaged;
    get simulate(): SeamHttpDevicesSimulate;
    delete(body?: DevicesDeleteBody): SeamHttpRequest<void, undefined>;
    get(body?: DevicesGetParams): SeamHttpRequest<DevicesGetResponse, 'device'>;
    list(body?: DevicesListParams): SeamHttpRequest<DevicesListResponse, 'devices'>;
    listDeviceProviders(body?: DevicesListDeviceProvidersParams): SeamHttpRequest<DevicesListDeviceProvidersResponse, 'device_providers'>;
    update(body?: DevicesUpdateBody): SeamHttpRequest<void, undefined>;
}
export type DevicesDeleteBody = RouteRequestBody<'/devices/delete'>;
export type DevicesDeleteResponse = SetNonNullable<Required<RouteResponse<'/devices/delete'>>>;
export type DevicesDeleteOptions = never;
export type DevicesGetParams = RouteRequestBody<'/devices/get'>;
export type DevicesGetResponse = SetNonNullable<Required<RouteResponse<'/devices/get'>>>;
export type DevicesGetOptions = never;
export type DevicesListParams = RouteRequestBody<'/devices/list'>;
export type DevicesListResponse = SetNonNullable<Required<RouteResponse<'/devices/list'>>>;
export type DevicesListOptions = never;
export type DevicesListDeviceProvidersParams = RouteRequestBody<'/devices/list_device_providers'>;
export type DevicesListDeviceProvidersResponse = SetNonNullable<Required<RouteResponse<'/devices/list_device_providers'>>>;
export type DevicesListDeviceProvidersOptions = never;
export type DevicesUpdateBody = RouteRequestBody<'/devices/update'>;
export type DevicesUpdateResponse = SetNonNullable<Required<RouteResponse<'/devices/update'>>>;
export type DevicesUpdateOptions = never;
