import { z } from 'zod';
export declare const hvac_mode_setting: z.ZodEnum<["off", "heat", "cool", "heat_cool"]>;
export type HvacModeSetting = z.infer<typeof hvac_mode_setting>;
export declare const fan_mode_setting: z.ZodEnum<["auto", "on"]>;
export type FanModeSetting = z.infer<typeof fan_mode_setting>;
export declare const climate_setting: z.ZodObject<{
    automatic_heating_enabled: z.ZodBoolean;
    automatic_cooling_enabled: z.ZodBoolean;
    hvac_mode_setting: z.ZodEnum<["off", "heat", "cool", "heat_cool"]>;
    cooling_set_point_celsius: z.ZodOptional<z.ZodNumber>;
    heating_set_point_celsius: z.ZodOptional<z.ZodNumber>;
    cooling_set_point_fahrenheit: z.ZodOptional<z.ZodNumber>;
    heating_set_point_fahrenheit: z.ZodOptional<z.ZodNumber>;
    manual_override_allowed: z.ZodBoolean;
}, "strip", z.ZodTypeAny, {
    automatic_heating_enabled: boolean;
    automatic_cooling_enabled: boolean;
    hvac_mode_setting: "off" | "heat" | "cool" | "heat_cool";
    manual_override_allowed: boolean;
    cooling_set_point_celsius?: number | undefined;
    heating_set_point_celsius?: number | undefined;
    cooling_set_point_fahrenheit?: number | undefined;
    heating_set_point_fahrenheit?: number | undefined;
}, {
    automatic_heating_enabled: boolean;
    automatic_cooling_enabled: boolean;
    hvac_mode_setting: "off" | "heat" | "cool" | "heat_cool";
    manual_override_allowed: boolean;
    cooling_set_point_celsius?: number | undefined;
    heating_set_point_celsius?: number | undefined;
    cooling_set_point_fahrenheit?: number | undefined;
    heating_set_point_fahrenheit?: number | undefined;
}>;
export type ClimateSetting = z.infer<typeof climate_setting>;
export declare const climate_setting_schedule: z.ZodObject<{
    name: z.ZodOptional<z.ZodString>;
    device_id: z.ZodString;
    created_at: z.ZodString;
    errors: z.ZodAny;
    climate_setting_schedule_id: z.ZodString;
    schedule_type: z.ZodLiteral<"time_bound">;
    schedule_starts_at: z.ZodString;
    schedule_ends_at: z.ZodString;
    automatic_heating_enabled: z.ZodOptional<z.ZodBoolean>;
    automatic_cooling_enabled: z.ZodOptional<z.ZodBoolean>;
    hvac_mode_setting: z.ZodOptional<z.ZodEnum<["off", "heat", "cool", "heat_cool"]>>;
    cooling_set_point_celsius: z.ZodOptional<z.ZodOptional<z.ZodNumber>>;
    heating_set_point_celsius: z.ZodOptional<z.ZodOptional<z.ZodNumber>>;
    cooling_set_point_fahrenheit: z.ZodOptional<z.ZodOptional<z.ZodNumber>>;
    heating_set_point_fahrenheit: z.ZodOptional<z.ZodOptional<z.ZodNumber>>;
    manual_override_allowed: z.ZodOptional<z.ZodBoolean>;
}, "strip", z.ZodTypeAny, {
    device_id: string;
    created_at: string;
    climate_setting_schedule_id: string;
    schedule_type: "time_bound";
    schedule_starts_at: string;
    schedule_ends_at: string;
    name?: string | undefined;
    errors?: any;
    automatic_heating_enabled?: boolean | undefined;
    automatic_cooling_enabled?: boolean | undefined;
    hvac_mode_setting?: "off" | "heat" | "cool" | "heat_cool" | undefined;
    cooling_set_point_celsius?: number | undefined;
    heating_set_point_celsius?: number | undefined;
    cooling_set_point_fahrenheit?: number | undefined;
    heating_set_point_fahrenheit?: number | undefined;
    manual_override_allowed?: boolean | undefined;
}, {
    device_id: string;
    created_at: string;
    climate_setting_schedule_id: string;
    schedule_type: "time_bound";
    schedule_starts_at: string;
    schedule_ends_at: string;
    name?: string | undefined;
    errors?: any;
    automatic_heating_enabled?: boolean | undefined;
    automatic_cooling_enabled?: boolean | undefined;
    hvac_mode_setting?: "off" | "heat" | "cool" | "heat_cool" | undefined;
    cooling_set_point_celsius?: number | undefined;
    heating_set_point_celsius?: number | undefined;
    cooling_set_point_fahrenheit?: number | undefined;
    heating_set_point_fahrenheit?: number | undefined;
    manual_override_allowed?: boolean | undefined;
}>;
export declare const cooling_thermostat_capability_properties: z.ZodObject<{
    temperature_fahrenheit: z.ZodNumber;
    temperature_celsius: z.ZodNumber;
    relative_humidity: z.ZodNumber;
    can_enable_automatic_heating: z.ZodBoolean;
    can_enable_automatic_cooling: z.ZodBoolean;
    available_hvac_mode_settings: z.ZodArray<z.ZodEnum<["off", "heat", "cool", "heat_cool"]>, "many">;
    is_heating_available: z.ZodLiteral<false>;
    is_heating: z.ZodBoolean;
    is_cooling: z.ZodBoolean;
    is_fan_running: z.ZodBoolean;
    fan_mode_setting: z.ZodEnum<["auto", "on"]>;
    is_temporary_manual_override_active: z.ZodBoolean;
    current_climate_setting: z.ZodObject<{
        automatic_heating_enabled: z.ZodBoolean;
        automatic_cooling_enabled: z.ZodBoolean;
        hvac_mode_setting: z.ZodEnum<["off", "heat", "cool", "heat_cool"]>;
        cooling_set_point_celsius: z.ZodOptional<z.ZodNumber>;
        heating_set_point_celsius: z.ZodOptional<z.ZodNumber>;
        cooling_set_point_fahrenheit: z.ZodOptional<z.ZodNumber>;
        heating_set_point_fahrenheit: z.ZodOptional<z.ZodNumber>;
        manual_override_allowed: z.ZodBoolean;
    }, "strip", z.ZodTypeAny, {
        automatic_heating_enabled: boolean;
        automatic_cooling_enabled: boolean;
        hvac_mode_setting: "off" | "heat" | "cool" | "heat_cool";
        manual_override_allowed: boolean;
        cooling_set_point_celsius?: number | undefined;
        heating_set_point_celsius?: number | undefined;
        cooling_set_point_fahrenheit?: number | undefined;
        heating_set_point_fahrenheit?: number | undefined;
    }, {
        automatic_heating_enabled: boolean;
        automatic_cooling_enabled: boolean;
        hvac_mode_setting: "off" | "heat" | "cool" | "heat_cool";
        manual_override_allowed: boolean;
        cooling_set_point_celsius?: number | undefined;
        heating_set_point_celsius?: number | undefined;
        cooling_set_point_fahrenheit?: number | undefined;
        heating_set_point_fahrenheit?: number | undefined;
    }>;
    default_climate_setting: z.ZodOptional<z.ZodObject<{
        automatic_heating_enabled: z.ZodBoolean;
        automatic_cooling_enabled: z.ZodBoolean;
        hvac_mode_setting: z.ZodEnum<["off", "heat", "cool", "heat_cool"]>;
        cooling_set_point_celsius: z.ZodOptional<z.ZodNumber>;
        heating_set_point_celsius: z.ZodOptional<z.ZodNumber>;
        cooling_set_point_fahrenheit: z.ZodOptional<z.ZodNumber>;
        heating_set_point_fahrenheit: z.ZodOptional<z.ZodNumber>;
        manual_override_allowed: z.ZodBoolean;
    }, "strip", z.ZodTypeAny, {
        automatic_heating_enabled: boolean;
        automatic_cooling_enabled: boolean;
        hvac_mode_setting: "off" | "heat" | "cool" | "heat_cool";
        manual_override_allowed: boolean;
        cooling_set_point_celsius?: number | undefined;
        heating_set_point_celsius?: number | undefined;
        cooling_set_point_fahrenheit?: number | undefined;
        heating_set_point_fahrenheit?: number | undefined;
    }, {
        automatic_heating_enabled: boolean;
        automatic_cooling_enabled: boolean;
        hvac_mode_setting: "off" | "heat" | "cool" | "heat_cool";
        manual_override_allowed: boolean;
        cooling_set_point_celsius?: number | undefined;
        heating_set_point_celsius?: number | undefined;
        cooling_set_point_fahrenheit?: number | undefined;
        heating_set_point_fahrenheit?: number | undefined;
    }>>;
    is_climate_setting_schedule_active: z.ZodBoolean;
    active_climate_setting_schedule: z.ZodOptional<z.ZodObject<{
        name: z.ZodOptional<z.ZodString>;
        device_id: z.ZodString;
        created_at: z.ZodString;
        errors: z.ZodAny;
        climate_setting_schedule_id: z.ZodString;
        schedule_type: z.ZodLiteral<"time_bound">;
        schedule_starts_at: z.ZodString;
        schedule_ends_at: z.ZodString;
        automatic_heating_enabled: z.ZodOptional<z.ZodBoolean>;
        automatic_cooling_enabled: z.ZodOptional<z.ZodBoolean>;
        hvac_mode_setting: z.ZodOptional<z.ZodEnum<["off", "heat", "cool", "heat_cool"]>>;
        cooling_set_point_celsius: z.ZodOptional<z.ZodOptional<z.ZodNumber>>;
        heating_set_point_celsius: z.ZodOptional<z.ZodOptional<z.ZodNumber>>;
        cooling_set_point_fahrenheit: z.ZodOptional<z.ZodOptional<z.ZodNumber>>;
        heating_set_point_fahrenheit: z.ZodOptional<z.ZodOptional<z.ZodNumber>>;
        manual_override_allowed: z.ZodOptional<z.ZodBoolean>;
    }, "strip", z.ZodTypeAny, {
        device_id: string;
        created_at: string;
        climate_setting_schedule_id: string;
        schedule_type: "time_bound";
        schedule_starts_at: string;
        schedule_ends_at: string;
        name?: string | undefined;
        errors?: any;
        automatic_heating_enabled?: boolean | undefined;
        automatic_cooling_enabled?: boolean | undefined;
        hvac_mode_setting?: "off" | "heat" | "cool" | "heat_cool" | undefined;
        cooling_set_point_celsius?: number | undefined;
        heating_set_point_celsius?: number | undefined;
        cooling_set_point_fahrenheit?: number | undefined;
        heating_set_point_fahrenheit?: number | undefined;
        manual_override_allowed?: boolean | undefined;
    }, {
        device_id: string;
        created_at: string;
        climate_setting_schedule_id: string;
        schedule_type: "time_bound";
        schedule_starts_at: string;
        schedule_ends_at: string;
        name?: string | undefined;
        errors?: any;
        automatic_heating_enabled?: boolean | undefined;
        automatic_cooling_enabled?: boolean | undefined;
        hvac_mode_setting?: "off" | "heat" | "cool" | "heat_cool" | undefined;
        cooling_set_point_celsius?: number | undefined;
        heating_set_point_celsius?: number | undefined;
        cooling_set_point_fahrenheit?: number | undefined;
        heating_set_point_fahrenheit?: number | undefined;
        manual_override_allowed?: boolean | undefined;
    }>>;
    min_cooling_set_point_celsius: z.ZodNumber;
    min_cooling_set_point_fahrenheit: z.ZodNumber;
    max_cooling_set_point_celsius: z.ZodNumber;
    max_cooling_set_point_fahrenheit: z.ZodNumber;
    is_cooling_available: z.ZodLiteral<true>;
}, "strip", z.ZodTypeAny, {
    temperature_fahrenheit: number;
    temperature_celsius: number;
    relative_humidity: number;
    can_enable_automatic_heating: boolean;
    can_enable_automatic_cooling: boolean;
    available_hvac_mode_settings: ("off" | "heat" | "cool" | "heat_cool")[];
    is_heating_available: false;
    is_cooling_available: true;
    is_heating: boolean;
    is_cooling: boolean;
    is_fan_running: boolean;
    fan_mode_setting: "auto" | "on";
    is_temporary_manual_override_active: boolean;
    current_climate_setting: {
        automatic_heating_enabled: boolean;
        automatic_cooling_enabled: boolean;
        hvac_mode_setting: "off" | "heat" | "cool" | "heat_cool";
        manual_override_allowed: boolean;
        cooling_set_point_celsius?: number | undefined;
        heating_set_point_celsius?: number | undefined;
        cooling_set_point_fahrenheit?: number | undefined;
        heating_set_point_fahrenheit?: number | undefined;
    };
    is_climate_setting_schedule_active: boolean;
    min_cooling_set_point_celsius: number;
    min_cooling_set_point_fahrenheit: number;
    max_cooling_set_point_celsius: number;
    max_cooling_set_point_fahrenheit: number;
    default_climate_setting?: {
        automatic_heating_enabled: boolean;
        automatic_cooling_enabled: boolean;
        hvac_mode_setting: "off" | "heat" | "cool" | "heat_cool";
        manual_override_allowed: boolean;
        cooling_set_point_celsius?: number | undefined;
        heating_set_point_celsius?: number | undefined;
        cooling_set_point_fahrenheit?: number | undefined;
        heating_set_point_fahrenheit?: number | undefined;
    } | undefined;
    active_climate_setting_schedule?: {
        device_id: string;
        created_at: string;
        climate_setting_schedule_id: string;
        schedule_type: "time_bound";
        schedule_starts_at: string;
        schedule_ends_at: string;
        name?: string | undefined;
        errors?: any;
        automatic_heating_enabled?: boolean | undefined;
        automatic_cooling_enabled?: boolean | undefined;
        hvac_mode_setting?: "off" | "heat" | "cool" | "heat_cool" | undefined;
        cooling_set_point_celsius?: number | undefined;
        heating_set_point_celsius?: number | undefined;
        cooling_set_point_fahrenheit?: number | undefined;
        heating_set_point_fahrenheit?: number | undefined;
        manual_override_allowed?: boolean | undefined;
    } | undefined;
}, {
    temperature_fahrenheit: number;
    temperature_celsius: number;
    relative_humidity: number;
    can_enable_automatic_heating: boolean;
    can_enable_automatic_cooling: boolean;
    available_hvac_mode_settings: ("off" | "heat" | "cool" | "heat_cool")[];
    is_heating_available: false;
    is_cooling_available: true;
    is_heating: boolean;
    is_cooling: boolean;
    is_fan_running: boolean;
    fan_mode_setting: "auto" | "on";
    is_temporary_manual_override_active: boolean;
    current_climate_setting: {
        automatic_heating_enabled: boolean;
        automatic_cooling_enabled: boolean;
        hvac_mode_setting: "off" | "heat" | "cool" | "heat_cool";
        manual_override_allowed: boolean;
        cooling_set_point_celsius?: number | undefined;
        heating_set_point_celsius?: number | undefined;
        cooling_set_point_fahrenheit?: number | undefined;
        heating_set_point_fahrenheit?: number | undefined;
    };
    is_climate_setting_schedule_active: boolean;
    min_cooling_set_point_celsius: number;
    min_cooling_set_point_fahrenheit: number;
    max_cooling_set_point_celsius: number;
    max_cooling_set_point_fahrenheit: number;
    default_climate_setting?: {
        automatic_heating_enabled: boolean;
        automatic_cooling_enabled: boolean;
        hvac_mode_setting: "off" | "heat" | "cool" | "heat_cool";
        manual_override_allowed: boolean;
        cooling_set_point_celsius?: number | undefined;
        heating_set_point_celsius?: number | undefined;
        cooling_set_point_fahrenheit?: number | undefined;
        heating_set_point_fahrenheit?: number | undefined;
    } | undefined;
    active_climate_setting_schedule?: {
        device_id: string;
        created_at: string;
        climate_setting_schedule_id: string;
        schedule_type: "time_bound";
        schedule_starts_at: string;
        schedule_ends_at: string;
        name?: string | undefined;
        errors?: any;
        automatic_heating_enabled?: boolean | undefined;
        automatic_cooling_enabled?: boolean | undefined;
        hvac_mode_setting?: "off" | "heat" | "cool" | "heat_cool" | undefined;
        cooling_set_point_celsius?: number | undefined;
        heating_set_point_celsius?: number | undefined;
        cooling_set_point_fahrenheit?: number | undefined;
        heating_set_point_fahrenheit?: number | undefined;
        manual_override_allowed?: boolean | undefined;
    } | undefined;
}>;
export declare const heating_thermostat_capability_properties: z.ZodObject<{
    temperature_fahrenheit: z.ZodNumber;
    temperature_celsius: z.ZodNumber;
    relative_humidity: z.ZodNumber;
    can_enable_automatic_heating: z.ZodBoolean;
    can_enable_automatic_cooling: z.ZodBoolean;
    available_hvac_mode_settings: z.ZodArray<z.ZodEnum<["off", "heat", "cool", "heat_cool"]>, "many">;
    is_cooling_available: z.ZodLiteral<false>;
    is_heating: z.ZodBoolean;
    is_cooling: z.ZodBoolean;
    is_fan_running: z.ZodBoolean;
    fan_mode_setting: z.ZodEnum<["auto", "on"]>;
    is_temporary_manual_override_active: z.ZodBoolean;
    current_climate_setting: z.ZodObject<{
        automatic_heating_enabled: z.ZodBoolean;
        automatic_cooling_enabled: z.ZodBoolean;
        hvac_mode_setting: z.ZodEnum<["off", "heat", "cool", "heat_cool"]>;
        cooling_set_point_celsius: z.ZodOptional<z.ZodNumber>;
        heating_set_point_celsius: z.ZodOptional<z.ZodNumber>;
        cooling_set_point_fahrenheit: z.ZodOptional<z.ZodNumber>;
        heating_set_point_fahrenheit: z.ZodOptional<z.ZodNumber>;
        manual_override_allowed: z.ZodBoolean;
    }, "strip", z.ZodTypeAny, {
        automatic_heating_enabled: boolean;
        automatic_cooling_enabled: boolean;
        hvac_mode_setting: "off" | "heat" | "cool" | "heat_cool";
        manual_override_allowed: boolean;
        cooling_set_point_celsius?: number | undefined;
        heating_set_point_celsius?: number | undefined;
        cooling_set_point_fahrenheit?: number | undefined;
        heating_set_point_fahrenheit?: number | undefined;
    }, {
        automatic_heating_enabled: boolean;
        automatic_cooling_enabled: boolean;
        hvac_mode_setting: "off" | "heat" | "cool" | "heat_cool";
        manual_override_allowed: boolean;
        cooling_set_point_celsius?: number | undefined;
        heating_set_point_celsius?: number | undefined;
        cooling_set_point_fahrenheit?: number | undefined;
        heating_set_point_fahrenheit?: number | undefined;
    }>;
    default_climate_setting: z.ZodOptional<z.ZodObject<{
        automatic_heating_enabled: z.ZodBoolean;
        automatic_cooling_enabled: z.ZodBoolean;
        hvac_mode_setting: z.ZodEnum<["off", "heat", "cool", "heat_cool"]>;
        cooling_set_point_celsius: z.ZodOptional<z.ZodNumber>;
        heating_set_point_celsius: z.ZodOptional<z.ZodNumber>;
        cooling_set_point_fahrenheit: z.ZodOptional<z.ZodNumber>;
        heating_set_point_fahrenheit: z.ZodOptional<z.ZodNumber>;
        manual_override_allowed: z.ZodBoolean;
    }, "strip", z.ZodTypeAny, {
        automatic_heating_enabled: boolean;
        automatic_cooling_enabled: boolean;
        hvac_mode_setting: "off" | "heat" | "cool" | "heat_cool";
        manual_override_allowed: boolean;
        cooling_set_point_celsius?: number | undefined;
        heating_set_point_celsius?: number | undefined;
        cooling_set_point_fahrenheit?: number | undefined;
        heating_set_point_fahrenheit?: number | undefined;
    }, {
        automatic_heating_enabled: boolean;
        automatic_cooling_enabled: boolean;
        hvac_mode_setting: "off" | "heat" | "cool" | "heat_cool";
        manual_override_allowed: boolean;
        cooling_set_point_celsius?: number | undefined;
        heating_set_point_celsius?: number | undefined;
        cooling_set_point_fahrenheit?: number | undefined;
        heating_set_point_fahrenheit?: number | undefined;
    }>>;
    is_climate_setting_schedule_active: z.ZodBoolean;
    active_climate_setting_schedule: z.ZodOptional<z.ZodObject<{
        name: z.ZodOptional<z.ZodString>;
        device_id: z.ZodString;
        created_at: z.ZodString;
        errors: z.ZodAny;
        climate_setting_schedule_id: z.ZodString;
        schedule_type: z.ZodLiteral<"time_bound">;
        schedule_starts_at: z.ZodString;
        schedule_ends_at: z.ZodString;
        automatic_heating_enabled: z.ZodOptional<z.ZodBoolean>;
        automatic_cooling_enabled: z.ZodOptional<z.ZodBoolean>;
        hvac_mode_setting: z.ZodOptional<z.ZodEnum<["off", "heat", "cool", "heat_cool"]>>;
        cooling_set_point_celsius: z.ZodOptional<z.ZodOptional<z.ZodNumber>>;
        heating_set_point_celsius: z.ZodOptional<z.ZodOptional<z.ZodNumber>>;
        cooling_set_point_fahrenheit: z.ZodOptional<z.ZodOptional<z.ZodNumber>>;
        heating_set_point_fahrenheit: z.ZodOptional<z.ZodOptional<z.ZodNumber>>;
        manual_override_allowed: z.ZodOptional<z.ZodBoolean>;
    }, "strip", z.ZodTypeAny, {
        device_id: string;
        created_at: string;
        climate_setting_schedule_id: string;
        schedule_type: "time_bound";
        schedule_starts_at: string;
        schedule_ends_at: string;
        name?: string | undefined;
        errors?: any;
        automatic_heating_enabled?: boolean | undefined;
        automatic_cooling_enabled?: boolean | undefined;
        hvac_mode_setting?: "off" | "heat" | "cool" | "heat_cool" | undefined;
        cooling_set_point_celsius?: number | undefined;
        heating_set_point_celsius?: number | undefined;
        cooling_set_point_fahrenheit?: number | undefined;
        heating_set_point_fahrenheit?: number | undefined;
        manual_override_allowed?: boolean | undefined;
    }, {
        device_id: string;
        created_at: string;
        climate_setting_schedule_id: string;
        schedule_type: "time_bound";
        schedule_starts_at: string;
        schedule_ends_at: string;
        name?: string | undefined;
        errors?: any;
        automatic_heating_enabled?: boolean | undefined;
        automatic_cooling_enabled?: boolean | undefined;
        hvac_mode_setting?: "off" | "heat" | "cool" | "heat_cool" | undefined;
        cooling_set_point_celsius?: number | undefined;
        heating_set_point_celsius?: number | undefined;
        cooling_set_point_fahrenheit?: number | undefined;
        heating_set_point_fahrenheit?: number | undefined;
        manual_override_allowed?: boolean | undefined;
    }>>;
    min_heating_set_point_celsius: z.ZodNumber;
    min_heating_set_point_fahrenheit: z.ZodNumber;
    max_heating_set_point_celsius: z.ZodNumber;
    max_heating_set_point_fahrenheit: z.ZodNumber;
    is_heating_available: z.ZodLiteral<true>;
}, "strip", z.ZodTypeAny, {
    temperature_fahrenheit: number;
    temperature_celsius: number;
    relative_humidity: number;
    can_enable_automatic_heating: boolean;
    can_enable_automatic_cooling: boolean;
    available_hvac_mode_settings: ("off" | "heat" | "cool" | "heat_cool")[];
    is_heating_available: true;
    is_cooling_available: false;
    is_heating: boolean;
    is_cooling: boolean;
    is_fan_running: boolean;
    fan_mode_setting: "auto" | "on";
    is_temporary_manual_override_active: boolean;
    current_climate_setting: {
        automatic_heating_enabled: boolean;
        automatic_cooling_enabled: boolean;
        hvac_mode_setting: "off" | "heat" | "cool" | "heat_cool";
        manual_override_allowed: boolean;
        cooling_set_point_celsius?: number | undefined;
        heating_set_point_celsius?: number | undefined;
        cooling_set_point_fahrenheit?: number | undefined;
        heating_set_point_fahrenheit?: number | undefined;
    };
    is_climate_setting_schedule_active: boolean;
    min_heating_set_point_celsius: number;
    min_heating_set_point_fahrenheit: number;
    max_heating_set_point_celsius: number;
    max_heating_set_point_fahrenheit: number;
    default_climate_setting?: {
        automatic_heating_enabled: boolean;
        automatic_cooling_enabled: boolean;
        hvac_mode_setting: "off" | "heat" | "cool" | "heat_cool";
        manual_override_allowed: boolean;
        cooling_set_point_celsius?: number | undefined;
        heating_set_point_celsius?: number | undefined;
        cooling_set_point_fahrenheit?: number | undefined;
        heating_set_point_fahrenheit?: number | undefined;
    } | undefined;
    active_climate_setting_schedule?: {
        device_id: string;
        created_at: string;
        climate_setting_schedule_id: string;
        schedule_type: "time_bound";
        schedule_starts_at: string;
        schedule_ends_at: string;
        name?: string | undefined;
        errors?: any;
        automatic_heating_enabled?: boolean | undefined;
        automatic_cooling_enabled?: boolean | undefined;
        hvac_mode_setting?: "off" | "heat" | "cool" | "heat_cool" | undefined;
        cooling_set_point_celsius?: number | undefined;
        heating_set_point_celsius?: number | undefined;
        cooling_set_point_fahrenheit?: number | undefined;
        heating_set_point_fahrenheit?: number | undefined;
        manual_override_allowed?: boolean | undefined;
    } | undefined;
}, {
    temperature_fahrenheit: number;
    temperature_celsius: number;
    relative_humidity: number;
    can_enable_automatic_heating: boolean;
    can_enable_automatic_cooling: boolean;
    available_hvac_mode_settings: ("off" | "heat" | "cool" | "heat_cool")[];
    is_heating_available: true;
    is_cooling_available: false;
    is_heating: boolean;
    is_cooling: boolean;
    is_fan_running: boolean;
    fan_mode_setting: "auto" | "on";
    is_temporary_manual_override_active: boolean;
    current_climate_setting: {
        automatic_heating_enabled: boolean;
        automatic_cooling_enabled: boolean;
        hvac_mode_setting: "off" | "heat" | "cool" | "heat_cool";
        manual_override_allowed: boolean;
        cooling_set_point_celsius?: number | undefined;
        heating_set_point_celsius?: number | undefined;
        cooling_set_point_fahrenheit?: number | undefined;
        heating_set_point_fahrenheit?: number | undefined;
    };
    is_climate_setting_schedule_active: boolean;
    min_heating_set_point_celsius: number;
    min_heating_set_point_fahrenheit: number;
    max_heating_set_point_celsius: number;
    max_heating_set_point_fahrenheit: number;
    default_climate_setting?: {
        automatic_heating_enabled: boolean;
        automatic_cooling_enabled: boolean;
        hvac_mode_setting: "off" | "heat" | "cool" | "heat_cool";
        manual_override_allowed: boolean;
        cooling_set_point_celsius?: number | undefined;
        heating_set_point_celsius?: number | undefined;
        cooling_set_point_fahrenheit?: number | undefined;
        heating_set_point_fahrenheit?: number | undefined;
    } | undefined;
    active_climate_setting_schedule?: {
        device_id: string;
        created_at: string;
        climate_setting_schedule_id: string;
        schedule_type: "time_bound";
        schedule_starts_at: string;
        schedule_ends_at: string;
        name?: string | undefined;
        errors?: any;
        automatic_heating_enabled?: boolean | undefined;
        automatic_cooling_enabled?: boolean | undefined;
        hvac_mode_setting?: "off" | "heat" | "cool" | "heat_cool" | undefined;
        cooling_set_point_celsius?: number | undefined;
        heating_set_point_celsius?: number | undefined;
        cooling_set_point_fahrenheit?: number | undefined;
        heating_set_point_fahrenheit?: number | undefined;
        manual_override_allowed?: boolean | undefined;
    } | undefined;
}>;
export declare const heating_cooling_thermostat_capability_properties: z.ZodObject<{
    temperature_fahrenheit: z.ZodNumber;
    temperature_celsius: z.ZodNumber;
    relative_humidity: z.ZodNumber;
    can_enable_automatic_heating: z.ZodBoolean;
    can_enable_automatic_cooling: z.ZodBoolean;
    available_hvac_mode_settings: z.ZodArray<z.ZodEnum<["off", "heat", "cool", "heat_cool"]>, "many">;
    is_heating: z.ZodBoolean;
    is_cooling: z.ZodBoolean;
    is_fan_running: z.ZodBoolean;
    fan_mode_setting: z.ZodEnum<["auto", "on"]>;
    is_temporary_manual_override_active: z.ZodBoolean;
    current_climate_setting: z.ZodObject<{
        automatic_heating_enabled: z.ZodBoolean;
        automatic_cooling_enabled: z.ZodBoolean;
        hvac_mode_setting: z.ZodEnum<["off", "heat", "cool", "heat_cool"]>;
        cooling_set_point_celsius: z.ZodOptional<z.ZodNumber>;
        heating_set_point_celsius: z.ZodOptional<z.ZodNumber>;
        cooling_set_point_fahrenheit: z.ZodOptional<z.ZodNumber>;
        heating_set_point_fahrenheit: z.ZodOptional<z.ZodNumber>;
        manual_override_allowed: z.ZodBoolean;
    }, "strip", z.ZodTypeAny, {
        automatic_heating_enabled: boolean;
        automatic_cooling_enabled: boolean;
        hvac_mode_setting: "off" | "heat" | "cool" | "heat_cool";
        manual_override_allowed: boolean;
        cooling_set_point_celsius?: number | undefined;
        heating_set_point_celsius?: number | undefined;
        cooling_set_point_fahrenheit?: number | undefined;
        heating_set_point_fahrenheit?: number | undefined;
    }, {
        automatic_heating_enabled: boolean;
        automatic_cooling_enabled: boolean;
        hvac_mode_setting: "off" | "heat" | "cool" | "heat_cool";
        manual_override_allowed: boolean;
        cooling_set_point_celsius?: number | undefined;
        heating_set_point_celsius?: number | undefined;
        cooling_set_point_fahrenheit?: number | undefined;
        heating_set_point_fahrenheit?: number | undefined;
    }>;
    default_climate_setting: z.ZodOptional<z.ZodObject<{
        automatic_heating_enabled: z.ZodBoolean;
        automatic_cooling_enabled: z.ZodBoolean;
        hvac_mode_setting: z.ZodEnum<["off", "heat", "cool", "heat_cool"]>;
        cooling_set_point_celsius: z.ZodOptional<z.ZodNumber>;
        heating_set_point_celsius: z.ZodOptional<z.ZodNumber>;
        cooling_set_point_fahrenheit: z.ZodOptional<z.ZodNumber>;
        heating_set_point_fahrenheit: z.ZodOptional<z.ZodNumber>;
        manual_override_allowed: z.ZodBoolean;
    }, "strip", z.ZodTypeAny, {
        automatic_heating_enabled: boolean;
        automatic_cooling_enabled: boolean;
        hvac_mode_setting: "off" | "heat" | "cool" | "heat_cool";
        manual_override_allowed: boolean;
        cooling_set_point_celsius?: number | undefined;
        heating_set_point_celsius?: number | undefined;
        cooling_set_point_fahrenheit?: number | undefined;
        heating_set_point_fahrenheit?: number | undefined;
    }, {
        automatic_heating_enabled: boolean;
        automatic_cooling_enabled: boolean;
        hvac_mode_setting: "off" | "heat" | "cool" | "heat_cool";
        manual_override_allowed: boolean;
        cooling_set_point_celsius?: number | undefined;
        heating_set_point_celsius?: number | undefined;
        cooling_set_point_fahrenheit?: number | undefined;
        heating_set_point_fahrenheit?: number | undefined;
    }>>;
    is_climate_setting_schedule_active: z.ZodBoolean;
    active_climate_setting_schedule: z.ZodOptional<z.ZodObject<{
        name: z.ZodOptional<z.ZodString>;
        device_id: z.ZodString;
        created_at: z.ZodString;
        errors: z.ZodAny;
        climate_setting_schedule_id: z.ZodString;
        schedule_type: z.ZodLiteral<"time_bound">;
        schedule_starts_at: z.ZodString;
        schedule_ends_at: z.ZodString;
        automatic_heating_enabled: z.ZodOptional<z.ZodBoolean>;
        automatic_cooling_enabled: z.ZodOptional<z.ZodBoolean>;
        hvac_mode_setting: z.ZodOptional<z.ZodEnum<["off", "heat", "cool", "heat_cool"]>>;
        cooling_set_point_celsius: z.ZodOptional<z.ZodOptional<z.ZodNumber>>;
        heating_set_point_celsius: z.ZodOptional<z.ZodOptional<z.ZodNumber>>;
        cooling_set_point_fahrenheit: z.ZodOptional<z.ZodOptional<z.ZodNumber>>;
        heating_set_point_fahrenheit: z.ZodOptional<z.ZodOptional<z.ZodNumber>>;
        manual_override_allowed: z.ZodOptional<z.ZodBoolean>;
    }, "strip", z.ZodTypeAny, {
        device_id: string;
        created_at: string;
        climate_setting_schedule_id: string;
        schedule_type: "time_bound";
        schedule_starts_at: string;
        schedule_ends_at: string;
        name?: string | undefined;
        errors?: any;
        automatic_heating_enabled?: boolean | undefined;
        automatic_cooling_enabled?: boolean | undefined;
        hvac_mode_setting?: "off" | "heat" | "cool" | "heat_cool" | undefined;
        cooling_set_point_celsius?: number | undefined;
        heating_set_point_celsius?: number | undefined;
        cooling_set_point_fahrenheit?: number | undefined;
        heating_set_point_fahrenheit?: number | undefined;
        manual_override_allowed?: boolean | undefined;
    }, {
        device_id: string;
        created_at: string;
        climate_setting_schedule_id: string;
        schedule_type: "time_bound";
        schedule_starts_at: string;
        schedule_ends_at: string;
        name?: string | undefined;
        errors?: any;
        automatic_heating_enabled?: boolean | undefined;
        automatic_cooling_enabled?: boolean | undefined;
        hvac_mode_setting?: "off" | "heat" | "cool" | "heat_cool" | undefined;
        cooling_set_point_celsius?: number | undefined;
        heating_set_point_celsius?: number | undefined;
        cooling_set_point_fahrenheit?: number | undefined;
        heating_set_point_fahrenheit?: number | undefined;
        manual_override_allowed?: boolean | undefined;
    }>>;
    min_cooling_set_point_celsius: z.ZodNumber;
    min_cooling_set_point_fahrenheit: z.ZodNumber;
    max_cooling_set_point_celsius: z.ZodNumber;
    max_cooling_set_point_fahrenheit: z.ZodNumber;
    min_heating_set_point_celsius: z.ZodNumber;
    min_heating_set_point_fahrenheit: z.ZodNumber;
    max_heating_set_point_celsius: z.ZodNumber;
    max_heating_set_point_fahrenheit: z.ZodNumber;
    is_cooling_available: z.ZodLiteral<true>;
    is_heating_available: z.ZodLiteral<true>;
    min_heating_cooling_delta_celsius: z.ZodNumber;
    min_heating_cooling_delta_fahrenheit: z.ZodNumber;
}, "strip", z.ZodTypeAny, {
    temperature_fahrenheit: number;
    temperature_celsius: number;
    relative_humidity: number;
    can_enable_automatic_heating: boolean;
    can_enable_automatic_cooling: boolean;
    available_hvac_mode_settings: ("off" | "heat" | "cool" | "heat_cool")[];
    is_heating_available: true;
    is_cooling_available: true;
    is_heating: boolean;
    is_cooling: boolean;
    is_fan_running: boolean;
    fan_mode_setting: "auto" | "on";
    is_temporary_manual_override_active: boolean;
    current_climate_setting: {
        automatic_heating_enabled: boolean;
        automatic_cooling_enabled: boolean;
        hvac_mode_setting: "off" | "heat" | "cool" | "heat_cool";
        manual_override_allowed: boolean;
        cooling_set_point_celsius?: number | undefined;
        heating_set_point_celsius?: number | undefined;
        cooling_set_point_fahrenheit?: number | undefined;
        heating_set_point_fahrenheit?: number | undefined;
    };
    is_climate_setting_schedule_active: boolean;
    min_cooling_set_point_celsius: number;
    min_cooling_set_point_fahrenheit: number;
    max_cooling_set_point_celsius: number;
    max_cooling_set_point_fahrenheit: number;
    min_heating_set_point_celsius: number;
    min_heating_set_point_fahrenheit: number;
    max_heating_set_point_celsius: number;
    max_heating_set_point_fahrenheit: number;
    min_heating_cooling_delta_celsius: number;
    min_heating_cooling_delta_fahrenheit: number;
    default_climate_setting?: {
        automatic_heating_enabled: boolean;
        automatic_cooling_enabled: boolean;
        hvac_mode_setting: "off" | "heat" | "cool" | "heat_cool";
        manual_override_allowed: boolean;
        cooling_set_point_celsius?: number | undefined;
        heating_set_point_celsius?: number | undefined;
        cooling_set_point_fahrenheit?: number | undefined;
        heating_set_point_fahrenheit?: number | undefined;
    } | undefined;
    active_climate_setting_schedule?: {
        device_id: string;
        created_at: string;
        climate_setting_schedule_id: string;
        schedule_type: "time_bound";
        schedule_starts_at: string;
        schedule_ends_at: string;
        name?: string | undefined;
        errors?: any;
        automatic_heating_enabled?: boolean | undefined;
        automatic_cooling_enabled?: boolean | undefined;
        hvac_mode_setting?: "off" | "heat" | "cool" | "heat_cool" | undefined;
        cooling_set_point_celsius?: number | undefined;
        heating_set_point_celsius?: number | undefined;
        cooling_set_point_fahrenheit?: number | undefined;
        heating_set_point_fahrenheit?: number | undefined;
        manual_override_allowed?: boolean | undefined;
    } | undefined;
}, {
    temperature_fahrenheit: number;
    temperature_celsius: number;
    relative_humidity: number;
    can_enable_automatic_heating: boolean;
    can_enable_automatic_cooling: boolean;
    available_hvac_mode_settings: ("off" | "heat" | "cool" | "heat_cool")[];
    is_heating_available: true;
    is_cooling_available: true;
    is_heating: boolean;
    is_cooling: boolean;
    is_fan_running: boolean;
    fan_mode_setting: "auto" | "on";
    is_temporary_manual_override_active: boolean;
    current_climate_setting: {
        automatic_heating_enabled: boolean;
        automatic_cooling_enabled: boolean;
        hvac_mode_setting: "off" | "heat" | "cool" | "heat_cool";
        manual_override_allowed: boolean;
        cooling_set_point_celsius?: number | undefined;
        heating_set_point_celsius?: number | undefined;
        cooling_set_point_fahrenheit?: number | undefined;
        heating_set_point_fahrenheit?: number | undefined;
    };
    is_climate_setting_schedule_active: boolean;
    min_cooling_set_point_celsius: number;
    min_cooling_set_point_fahrenheit: number;
    max_cooling_set_point_celsius: number;
    max_cooling_set_point_fahrenheit: number;
    min_heating_set_point_celsius: number;
    min_heating_set_point_fahrenheit: number;
    max_heating_set_point_celsius: number;
    max_heating_set_point_fahrenheit: number;
    min_heating_cooling_delta_celsius: number;
    min_heating_cooling_delta_fahrenheit: number;
    default_climate_setting?: {
        automatic_heating_enabled: boolean;
        automatic_cooling_enabled: boolean;
        hvac_mode_setting: "off" | "heat" | "cool" | "heat_cool";
        manual_override_allowed: boolean;
        cooling_set_point_celsius?: number | undefined;
        heating_set_point_celsius?: number | undefined;
        cooling_set_point_fahrenheit?: number | undefined;
        heating_set_point_fahrenheit?: number | undefined;
    } | undefined;
    active_climate_setting_schedule?: {
        device_id: string;
        created_at: string;
        climate_setting_schedule_id: string;
        schedule_type: "time_bound";
        schedule_starts_at: string;
        schedule_ends_at: string;
        name?: string | undefined;
        errors?: any;
        automatic_heating_enabled?: boolean | undefined;
        automatic_cooling_enabled?: boolean | undefined;
        hvac_mode_setting?: "off" | "heat" | "cool" | "heat_cool" | undefined;
        cooling_set_point_celsius?: number | undefined;
        heating_set_point_celsius?: number | undefined;
        cooling_set_point_fahrenheit?: number | undefined;
        heating_set_point_fahrenheit?: number | undefined;
        manual_override_allowed?: boolean | undefined;
    } | undefined;
}>;
export declare const thermostat_capability_properties: z.ZodUnion<[z.ZodObject<{
    temperature_fahrenheit: z.ZodOptional<z.ZodNumber>;
    temperature_celsius: z.ZodOptional<z.ZodNumber>;
    relative_humidity: z.ZodOptional<z.ZodNumber>;
    can_enable_automatic_heating: z.ZodOptional<z.ZodBoolean>;
    can_enable_automatic_cooling: z.ZodOptional<z.ZodBoolean>;
    available_hvac_mode_settings: z.ZodOptional<z.ZodArray<z.ZodEnum<["off", "heat", "cool", "heat_cool"]>, "many">>;
    is_heating: z.ZodOptional<z.ZodBoolean>;
    is_cooling: z.ZodOptional<z.ZodBoolean>;
    is_fan_running: z.ZodOptional<z.ZodBoolean>;
    fan_mode_setting: z.ZodOptional<z.ZodEnum<["auto", "on"]>>;
    is_temporary_manual_override_active: z.ZodOptional<z.ZodBoolean>;
    current_climate_setting: z.ZodOptional<z.ZodObject<{
        automatic_heating_enabled: z.ZodBoolean;
        automatic_cooling_enabled: z.ZodBoolean;
        hvac_mode_setting: z.ZodEnum<["off", "heat", "cool", "heat_cool"]>;
        cooling_set_point_celsius: z.ZodOptional<z.ZodNumber>;
        heating_set_point_celsius: z.ZodOptional<z.ZodNumber>;
        cooling_set_point_fahrenheit: z.ZodOptional<z.ZodNumber>;
        heating_set_point_fahrenheit: z.ZodOptional<z.ZodNumber>;
        manual_override_allowed: z.ZodBoolean;
    }, "strip", z.ZodTypeAny, {
        automatic_heating_enabled: boolean;
        automatic_cooling_enabled: boolean;
        hvac_mode_setting: "off" | "heat" | "cool" | "heat_cool";
        manual_override_allowed: boolean;
        cooling_set_point_celsius?: number | undefined;
        heating_set_point_celsius?: number | undefined;
        cooling_set_point_fahrenheit?: number | undefined;
        heating_set_point_fahrenheit?: number | undefined;
    }, {
        automatic_heating_enabled: boolean;
        automatic_cooling_enabled: boolean;
        hvac_mode_setting: "off" | "heat" | "cool" | "heat_cool";
        manual_override_allowed: boolean;
        cooling_set_point_celsius?: number | undefined;
        heating_set_point_celsius?: number | undefined;
        cooling_set_point_fahrenheit?: number | undefined;
        heating_set_point_fahrenheit?: number | undefined;
    }>>;
    default_climate_setting: z.ZodOptional<z.ZodOptional<z.ZodObject<{
        automatic_heating_enabled: z.ZodBoolean;
        automatic_cooling_enabled: z.ZodBoolean;
        hvac_mode_setting: z.ZodEnum<["off", "heat", "cool", "heat_cool"]>;
        cooling_set_point_celsius: z.ZodOptional<z.ZodNumber>;
        heating_set_point_celsius: z.ZodOptional<z.ZodNumber>;
        cooling_set_point_fahrenheit: z.ZodOptional<z.ZodNumber>;
        heating_set_point_fahrenheit: z.ZodOptional<z.ZodNumber>;
        manual_override_allowed: z.ZodBoolean;
    }, "strip", z.ZodTypeAny, {
        automatic_heating_enabled: boolean;
        automatic_cooling_enabled: boolean;
        hvac_mode_setting: "off" | "heat" | "cool" | "heat_cool";
        manual_override_allowed: boolean;
        cooling_set_point_celsius?: number | undefined;
        heating_set_point_celsius?: number | undefined;
        cooling_set_point_fahrenheit?: number | undefined;
        heating_set_point_fahrenheit?: number | undefined;
    }, {
        automatic_heating_enabled: boolean;
        automatic_cooling_enabled: boolean;
        hvac_mode_setting: "off" | "heat" | "cool" | "heat_cool";
        manual_override_allowed: boolean;
        cooling_set_point_celsius?: number | undefined;
        heating_set_point_celsius?: number | undefined;
        cooling_set_point_fahrenheit?: number | undefined;
        heating_set_point_fahrenheit?: number | undefined;
    }>>>;
    is_climate_setting_schedule_active: z.ZodOptional<z.ZodBoolean>;
    active_climate_setting_schedule: z.ZodOptional<z.ZodOptional<z.ZodObject<{
        name: z.ZodOptional<z.ZodString>;
        device_id: z.ZodString;
        created_at: z.ZodString;
        errors: z.ZodAny;
        climate_setting_schedule_id: z.ZodString;
        schedule_type: z.ZodLiteral<"time_bound">;
        schedule_starts_at: z.ZodString;
        schedule_ends_at: z.ZodString;
        automatic_heating_enabled: z.ZodOptional<z.ZodBoolean>;
        automatic_cooling_enabled: z.ZodOptional<z.ZodBoolean>;
        hvac_mode_setting: z.ZodOptional<z.ZodEnum<["off", "heat", "cool", "heat_cool"]>>;
        cooling_set_point_celsius: z.ZodOptional<z.ZodOptional<z.ZodNumber>>;
        heating_set_point_celsius: z.ZodOptional<z.ZodOptional<z.ZodNumber>>;
        cooling_set_point_fahrenheit: z.ZodOptional<z.ZodOptional<z.ZodNumber>>;
        heating_set_point_fahrenheit: z.ZodOptional<z.ZodOptional<z.ZodNumber>>;
        manual_override_allowed: z.ZodOptional<z.ZodBoolean>;
    }, "strip", z.ZodTypeAny, {
        device_id: string;
        created_at: string;
        climate_setting_schedule_id: string;
        schedule_type: "time_bound";
        schedule_starts_at: string;
        schedule_ends_at: string;
        name?: string | undefined;
        errors?: any;
        automatic_heating_enabled?: boolean | undefined;
        automatic_cooling_enabled?: boolean | undefined;
        hvac_mode_setting?: "off" | "heat" | "cool" | "heat_cool" | undefined;
        cooling_set_point_celsius?: number | undefined;
        heating_set_point_celsius?: number | undefined;
        cooling_set_point_fahrenheit?: number | undefined;
        heating_set_point_fahrenheit?: number | undefined;
        manual_override_allowed?: boolean | undefined;
    }, {
        device_id: string;
        created_at: string;
        climate_setting_schedule_id: string;
        schedule_type: "time_bound";
        schedule_starts_at: string;
        schedule_ends_at: string;
        name?: string | undefined;
        errors?: any;
        automatic_heating_enabled?: boolean | undefined;
        automatic_cooling_enabled?: boolean | undefined;
        hvac_mode_setting?: "off" | "heat" | "cool" | "heat_cool" | undefined;
        cooling_set_point_celsius?: number | undefined;
        heating_set_point_celsius?: number | undefined;
        cooling_set_point_fahrenheit?: number | undefined;
        heating_set_point_fahrenheit?: number | undefined;
        manual_override_allowed?: boolean | undefined;
    }>>>;
    min_cooling_set_point_celsius: z.ZodOptional<z.ZodNumber>;
    min_cooling_set_point_fahrenheit: z.ZodOptional<z.ZodNumber>;
    max_cooling_set_point_celsius: z.ZodOptional<z.ZodNumber>;
    max_cooling_set_point_fahrenheit: z.ZodOptional<z.ZodNumber>;
    min_heating_set_point_celsius: z.ZodOptional<z.ZodNumber>;
    min_heating_set_point_fahrenheit: z.ZodOptional<z.ZodNumber>;
    max_heating_set_point_celsius: z.ZodOptional<z.ZodNumber>;
    max_heating_set_point_fahrenheit: z.ZodOptional<z.ZodNumber>;
    is_cooling_available: z.ZodOptional<z.ZodLiteral<true>>;
    is_heating_available: z.ZodOptional<z.ZodLiteral<true>>;
    min_heating_cooling_delta_celsius: z.ZodOptional<z.ZodNumber>;
    min_heating_cooling_delta_fahrenheit: z.ZodOptional<z.ZodNumber>;
}, "strip", z.ZodTypeAny, {
    temperature_fahrenheit?: number | undefined;
    temperature_celsius?: number | undefined;
    relative_humidity?: number | undefined;
    can_enable_automatic_heating?: boolean | undefined;
    can_enable_automatic_cooling?: boolean | undefined;
    available_hvac_mode_settings?: ("off" | "heat" | "cool" | "heat_cool")[] | undefined;
    is_heating?: boolean | undefined;
    is_cooling?: boolean | undefined;
    is_fan_running?: boolean | undefined;
    fan_mode_setting?: "auto" | "on" | undefined;
    is_temporary_manual_override_active?: boolean | undefined;
    current_climate_setting?: {
        automatic_heating_enabled: boolean;
        automatic_cooling_enabled: boolean;
        hvac_mode_setting: "off" | "heat" | "cool" | "heat_cool";
        manual_override_allowed: boolean;
        cooling_set_point_celsius?: number | undefined;
        heating_set_point_celsius?: number | undefined;
        cooling_set_point_fahrenheit?: number | undefined;
        heating_set_point_fahrenheit?: number | undefined;
    } | undefined;
    default_climate_setting?: {
        automatic_heating_enabled: boolean;
        automatic_cooling_enabled: boolean;
        hvac_mode_setting: "off" | "heat" | "cool" | "heat_cool";
        manual_override_allowed: boolean;
        cooling_set_point_celsius?: number | undefined;
        heating_set_point_celsius?: number | undefined;
        cooling_set_point_fahrenheit?: number | undefined;
        heating_set_point_fahrenheit?: number | undefined;
    } | undefined;
    is_climate_setting_schedule_active?: boolean | undefined;
    active_climate_setting_schedule?: {
        device_id: string;
        created_at: string;
        climate_setting_schedule_id: string;
        schedule_type: "time_bound";
        schedule_starts_at: string;
        schedule_ends_at: string;
        name?: string | undefined;
        errors?: any;
        automatic_heating_enabled?: boolean | undefined;
        automatic_cooling_enabled?: boolean | undefined;
        hvac_mode_setting?: "off" | "heat" | "cool" | "heat_cool" | undefined;
        cooling_set_point_celsius?: number | undefined;
        heating_set_point_celsius?: number | undefined;
        cooling_set_point_fahrenheit?: number | undefined;
        heating_set_point_fahrenheit?: number | undefined;
        manual_override_allowed?: boolean | undefined;
    } | undefined;
    min_cooling_set_point_celsius?: number | undefined;
    min_cooling_set_point_fahrenheit?: number | undefined;
    max_cooling_set_point_celsius?: number | undefined;
    max_cooling_set_point_fahrenheit?: number | undefined;
    min_heating_set_point_celsius?: number | undefined;
    min_heating_set_point_fahrenheit?: number | undefined;
    max_heating_set_point_celsius?: number | undefined;
    max_heating_set_point_fahrenheit?: number | undefined;
    is_cooling_available?: true | undefined;
    is_heating_available?: true | undefined;
    min_heating_cooling_delta_celsius?: number | undefined;
    min_heating_cooling_delta_fahrenheit?: number | undefined;
}, {
    temperature_fahrenheit?: number | undefined;
    temperature_celsius?: number | undefined;
    relative_humidity?: number | undefined;
    can_enable_automatic_heating?: boolean | undefined;
    can_enable_automatic_cooling?: boolean | undefined;
    available_hvac_mode_settings?: ("off" | "heat" | "cool" | "heat_cool")[] | undefined;
    is_heating?: boolean | undefined;
    is_cooling?: boolean | undefined;
    is_fan_running?: boolean | undefined;
    fan_mode_setting?: "auto" | "on" | undefined;
    is_temporary_manual_override_active?: boolean | undefined;
    current_climate_setting?: {
        automatic_heating_enabled: boolean;
        automatic_cooling_enabled: boolean;
        hvac_mode_setting: "off" | "heat" | "cool" | "heat_cool";
        manual_override_allowed: boolean;
        cooling_set_point_celsius?: number | undefined;
        heating_set_point_celsius?: number | undefined;
        cooling_set_point_fahrenheit?: number | undefined;
        heating_set_point_fahrenheit?: number | undefined;
    } | undefined;
    default_climate_setting?: {
        automatic_heating_enabled: boolean;
        automatic_cooling_enabled: boolean;
        hvac_mode_setting: "off" | "heat" | "cool" | "heat_cool";
        manual_override_allowed: boolean;
        cooling_set_point_celsius?: number | undefined;
        heating_set_point_celsius?: number | undefined;
        cooling_set_point_fahrenheit?: number | undefined;
        heating_set_point_fahrenheit?: number | undefined;
    } | undefined;
    is_climate_setting_schedule_active?: boolean | undefined;
    active_climate_setting_schedule?: {
        device_id: string;
        created_at: string;
        climate_setting_schedule_id: string;
        schedule_type: "time_bound";
        schedule_starts_at: string;
        schedule_ends_at: string;
        name?: string | undefined;
        errors?: any;
        automatic_heating_enabled?: boolean | undefined;
        automatic_cooling_enabled?: boolean | undefined;
        hvac_mode_setting?: "off" | "heat" | "cool" | "heat_cool" | undefined;
        cooling_set_point_celsius?: number | undefined;
        heating_set_point_celsius?: number | undefined;
        cooling_set_point_fahrenheit?: number | undefined;
        heating_set_point_fahrenheit?: number | undefined;
        manual_override_allowed?: boolean | undefined;
    } | undefined;
    min_cooling_set_point_celsius?: number | undefined;
    min_cooling_set_point_fahrenheit?: number | undefined;
    max_cooling_set_point_celsius?: number | undefined;
    max_cooling_set_point_fahrenheit?: number | undefined;
    min_heating_set_point_celsius?: number | undefined;
    min_heating_set_point_fahrenheit?: number | undefined;
    max_heating_set_point_celsius?: number | undefined;
    max_heating_set_point_fahrenheit?: number | undefined;
    is_cooling_available?: true | undefined;
    is_heating_available?: true | undefined;
    min_heating_cooling_delta_celsius?: number | undefined;
    min_heating_cooling_delta_fahrenheit?: number | undefined;
}>, z.ZodObject<{
    temperature_fahrenheit: z.ZodOptional<z.ZodNumber>;
    temperature_celsius: z.ZodOptional<z.ZodNumber>;
    relative_humidity: z.ZodOptional<z.ZodNumber>;
    can_enable_automatic_heating: z.ZodOptional<z.ZodBoolean>;
    can_enable_automatic_cooling: z.ZodOptional<z.ZodBoolean>;
    available_hvac_mode_settings: z.ZodOptional<z.ZodArray<z.ZodEnum<["off", "heat", "cool", "heat_cool"]>, "many">>;
    is_cooling_available: z.ZodOptional<z.ZodLiteral<false>>;
    is_heating: z.ZodOptional<z.ZodBoolean>;
    is_cooling: z.ZodOptional<z.ZodBoolean>;
    is_fan_running: z.ZodOptional<z.ZodBoolean>;
    fan_mode_setting: z.ZodOptional<z.ZodEnum<["auto", "on"]>>;
    is_temporary_manual_override_active: z.ZodOptional<z.ZodBoolean>;
    current_climate_setting: z.ZodOptional<z.ZodObject<{
        automatic_heating_enabled: z.ZodBoolean;
        automatic_cooling_enabled: z.ZodBoolean;
        hvac_mode_setting: z.ZodEnum<["off", "heat", "cool", "heat_cool"]>;
        cooling_set_point_celsius: z.ZodOptional<z.ZodNumber>;
        heating_set_point_celsius: z.ZodOptional<z.ZodNumber>;
        cooling_set_point_fahrenheit: z.ZodOptional<z.ZodNumber>;
        heating_set_point_fahrenheit: z.ZodOptional<z.ZodNumber>;
        manual_override_allowed: z.ZodBoolean;
    }, "strip", z.ZodTypeAny, {
        automatic_heating_enabled: boolean;
        automatic_cooling_enabled: boolean;
        hvac_mode_setting: "off" | "heat" | "cool" | "heat_cool";
        manual_override_allowed: boolean;
        cooling_set_point_celsius?: number | undefined;
        heating_set_point_celsius?: number | undefined;
        cooling_set_point_fahrenheit?: number | undefined;
        heating_set_point_fahrenheit?: number | undefined;
    }, {
        automatic_heating_enabled: boolean;
        automatic_cooling_enabled: boolean;
        hvac_mode_setting: "off" | "heat" | "cool" | "heat_cool";
        manual_override_allowed: boolean;
        cooling_set_point_celsius?: number | undefined;
        heating_set_point_celsius?: number | undefined;
        cooling_set_point_fahrenheit?: number | undefined;
        heating_set_point_fahrenheit?: number | undefined;
    }>>;
    default_climate_setting: z.ZodOptional<z.ZodOptional<z.ZodObject<{
        automatic_heating_enabled: z.ZodBoolean;
        automatic_cooling_enabled: z.ZodBoolean;
        hvac_mode_setting: z.ZodEnum<["off", "heat", "cool", "heat_cool"]>;
        cooling_set_point_celsius: z.ZodOptional<z.ZodNumber>;
        heating_set_point_celsius: z.ZodOptional<z.ZodNumber>;
        cooling_set_point_fahrenheit: z.ZodOptional<z.ZodNumber>;
        heating_set_point_fahrenheit: z.ZodOptional<z.ZodNumber>;
        manual_override_allowed: z.ZodBoolean;
    }, "strip", z.ZodTypeAny, {
        automatic_heating_enabled: boolean;
        automatic_cooling_enabled: boolean;
        hvac_mode_setting: "off" | "heat" | "cool" | "heat_cool";
        manual_override_allowed: boolean;
        cooling_set_point_celsius?: number | undefined;
        heating_set_point_celsius?: number | undefined;
        cooling_set_point_fahrenheit?: number | undefined;
        heating_set_point_fahrenheit?: number | undefined;
    }, {
        automatic_heating_enabled: boolean;
        automatic_cooling_enabled: boolean;
        hvac_mode_setting: "off" | "heat" | "cool" | "heat_cool";
        manual_override_allowed: boolean;
        cooling_set_point_celsius?: number | undefined;
        heating_set_point_celsius?: number | undefined;
        cooling_set_point_fahrenheit?: number | undefined;
        heating_set_point_fahrenheit?: number | undefined;
    }>>>;
    is_climate_setting_schedule_active: z.ZodOptional<z.ZodBoolean>;
    active_climate_setting_schedule: z.ZodOptional<z.ZodOptional<z.ZodObject<{
        name: z.ZodOptional<z.ZodString>;
        device_id: z.ZodString;
        created_at: z.ZodString;
        errors: z.ZodAny;
        climate_setting_schedule_id: z.ZodString;
        schedule_type: z.ZodLiteral<"time_bound">;
        schedule_starts_at: z.ZodString;
        schedule_ends_at: z.ZodString;
        automatic_heating_enabled: z.ZodOptional<z.ZodBoolean>;
        automatic_cooling_enabled: z.ZodOptional<z.ZodBoolean>;
        hvac_mode_setting: z.ZodOptional<z.ZodEnum<["off", "heat", "cool", "heat_cool"]>>;
        cooling_set_point_celsius: z.ZodOptional<z.ZodOptional<z.ZodNumber>>;
        heating_set_point_celsius: z.ZodOptional<z.ZodOptional<z.ZodNumber>>;
        cooling_set_point_fahrenheit: z.ZodOptional<z.ZodOptional<z.ZodNumber>>;
        heating_set_point_fahrenheit: z.ZodOptional<z.ZodOptional<z.ZodNumber>>;
        manual_override_allowed: z.ZodOptional<z.ZodBoolean>;
    }, "strip", z.ZodTypeAny, {
        device_id: string;
        created_at: string;
        climate_setting_schedule_id: string;
        schedule_type: "time_bound";
        schedule_starts_at: string;
        schedule_ends_at: string;
        name?: string | undefined;
        errors?: any;
        automatic_heating_enabled?: boolean | undefined;
        automatic_cooling_enabled?: boolean | undefined;
        hvac_mode_setting?: "off" | "heat" | "cool" | "heat_cool" | undefined;
        cooling_set_point_celsius?: number | undefined;
        heating_set_point_celsius?: number | undefined;
        cooling_set_point_fahrenheit?: number | undefined;
        heating_set_point_fahrenheit?: number | undefined;
        manual_override_allowed?: boolean | undefined;
    }, {
        device_id: string;
        created_at: string;
        climate_setting_schedule_id: string;
        schedule_type: "time_bound";
        schedule_starts_at: string;
        schedule_ends_at: string;
        name?: string | undefined;
        errors?: any;
        automatic_heating_enabled?: boolean | undefined;
        automatic_cooling_enabled?: boolean | undefined;
        hvac_mode_setting?: "off" | "heat" | "cool" | "heat_cool" | undefined;
        cooling_set_point_celsius?: number | undefined;
        heating_set_point_celsius?: number | undefined;
        cooling_set_point_fahrenheit?: number | undefined;
        heating_set_point_fahrenheit?: number | undefined;
        manual_override_allowed?: boolean | undefined;
    }>>>;
    min_heating_set_point_celsius: z.ZodOptional<z.ZodNumber>;
    min_heating_set_point_fahrenheit: z.ZodOptional<z.ZodNumber>;
    max_heating_set_point_celsius: z.ZodOptional<z.ZodNumber>;
    max_heating_set_point_fahrenheit: z.ZodOptional<z.ZodNumber>;
    is_heating_available: z.ZodOptional<z.ZodLiteral<true>>;
}, "strip", z.ZodTypeAny, {
    temperature_fahrenheit?: number | undefined;
    temperature_celsius?: number | undefined;
    relative_humidity?: number | undefined;
    can_enable_automatic_heating?: boolean | undefined;
    can_enable_automatic_cooling?: boolean | undefined;
    available_hvac_mode_settings?: ("off" | "heat" | "cool" | "heat_cool")[] | undefined;
    is_cooling_available?: false | undefined;
    is_heating?: boolean | undefined;
    is_cooling?: boolean | undefined;
    is_fan_running?: boolean | undefined;
    fan_mode_setting?: "auto" | "on" | undefined;
    is_temporary_manual_override_active?: boolean | undefined;
    current_climate_setting?: {
        automatic_heating_enabled: boolean;
        automatic_cooling_enabled: boolean;
        hvac_mode_setting: "off" | "heat" | "cool" | "heat_cool";
        manual_override_allowed: boolean;
        cooling_set_point_celsius?: number | undefined;
        heating_set_point_celsius?: number | undefined;
        cooling_set_point_fahrenheit?: number | undefined;
        heating_set_point_fahrenheit?: number | undefined;
    } | undefined;
    default_climate_setting?: {
        automatic_heating_enabled: boolean;
        automatic_cooling_enabled: boolean;
        hvac_mode_setting: "off" | "heat" | "cool" | "heat_cool";
        manual_override_allowed: boolean;
        cooling_set_point_celsius?: number | undefined;
        heating_set_point_celsius?: number | undefined;
        cooling_set_point_fahrenheit?: number | undefined;
        heating_set_point_fahrenheit?: number | undefined;
    } | undefined;
    is_climate_setting_schedule_active?: boolean | undefined;
    active_climate_setting_schedule?: {
        device_id: string;
        created_at: string;
        climate_setting_schedule_id: string;
        schedule_type: "time_bound";
        schedule_starts_at: string;
        schedule_ends_at: string;
        name?: string | undefined;
        errors?: any;
        automatic_heating_enabled?: boolean | undefined;
        automatic_cooling_enabled?: boolean | undefined;
        hvac_mode_setting?: "off" | "heat" | "cool" | "heat_cool" | undefined;
        cooling_set_point_celsius?: number | undefined;
        heating_set_point_celsius?: number | undefined;
        cooling_set_point_fahrenheit?: number | undefined;
        heating_set_point_fahrenheit?: number | undefined;
        manual_override_allowed?: boolean | undefined;
    } | undefined;
    min_heating_set_point_celsius?: number | undefined;
    min_heating_set_point_fahrenheit?: number | undefined;
    max_heating_set_point_celsius?: number | undefined;
    max_heating_set_point_fahrenheit?: number | undefined;
    is_heating_available?: true | undefined;
}, {
    temperature_fahrenheit?: number | undefined;
    temperature_celsius?: number | undefined;
    relative_humidity?: number | undefined;
    can_enable_automatic_heating?: boolean | undefined;
    can_enable_automatic_cooling?: boolean | undefined;
    available_hvac_mode_settings?: ("off" | "heat" | "cool" | "heat_cool")[] | undefined;
    is_cooling_available?: false | undefined;
    is_heating?: boolean | undefined;
    is_cooling?: boolean | undefined;
    is_fan_running?: boolean | undefined;
    fan_mode_setting?: "auto" | "on" | undefined;
    is_temporary_manual_override_active?: boolean | undefined;
    current_climate_setting?: {
        automatic_heating_enabled: boolean;
        automatic_cooling_enabled: boolean;
        hvac_mode_setting: "off" | "heat" | "cool" | "heat_cool";
        manual_override_allowed: boolean;
        cooling_set_point_celsius?: number | undefined;
        heating_set_point_celsius?: number | undefined;
        cooling_set_point_fahrenheit?: number | undefined;
        heating_set_point_fahrenheit?: number | undefined;
    } | undefined;
    default_climate_setting?: {
        automatic_heating_enabled: boolean;
        automatic_cooling_enabled: boolean;
        hvac_mode_setting: "off" | "heat" | "cool" | "heat_cool";
        manual_override_allowed: boolean;
        cooling_set_point_celsius?: number | undefined;
        heating_set_point_celsius?: number | undefined;
        cooling_set_point_fahrenheit?: number | undefined;
        heating_set_point_fahrenheit?: number | undefined;
    } | undefined;
    is_climate_setting_schedule_active?: boolean | undefined;
    active_climate_setting_schedule?: {
        device_id: string;
        created_at: string;
        climate_setting_schedule_id: string;
        schedule_type: "time_bound";
        schedule_starts_at: string;
        schedule_ends_at: string;
        name?: string | undefined;
        errors?: any;
        automatic_heating_enabled?: boolean | undefined;
        automatic_cooling_enabled?: boolean | undefined;
        hvac_mode_setting?: "off" | "heat" | "cool" | "heat_cool" | undefined;
        cooling_set_point_celsius?: number | undefined;
        heating_set_point_celsius?: number | undefined;
        cooling_set_point_fahrenheit?: number | undefined;
        heating_set_point_fahrenheit?: number | undefined;
        manual_override_allowed?: boolean | undefined;
    } | undefined;
    min_heating_set_point_celsius?: number | undefined;
    min_heating_set_point_fahrenheit?: number | undefined;
    max_heating_set_point_celsius?: number | undefined;
    max_heating_set_point_fahrenheit?: number | undefined;
    is_heating_available?: true | undefined;
}>, z.ZodObject<{
    temperature_fahrenheit: z.ZodOptional<z.ZodNumber>;
    temperature_celsius: z.ZodOptional<z.ZodNumber>;
    relative_humidity: z.ZodOptional<z.ZodNumber>;
    can_enable_automatic_heating: z.ZodOptional<z.ZodBoolean>;
    can_enable_automatic_cooling: z.ZodOptional<z.ZodBoolean>;
    available_hvac_mode_settings: z.ZodOptional<z.ZodArray<z.ZodEnum<["off", "heat", "cool", "heat_cool"]>, "many">>;
    is_heating_available: z.ZodOptional<z.ZodLiteral<false>>;
    is_heating: z.ZodOptional<z.ZodBoolean>;
    is_cooling: z.ZodOptional<z.ZodBoolean>;
    is_fan_running: z.ZodOptional<z.ZodBoolean>;
    fan_mode_setting: z.ZodOptional<z.ZodEnum<["auto", "on"]>>;
    is_temporary_manual_override_active: z.ZodOptional<z.ZodBoolean>;
    current_climate_setting: z.ZodOptional<z.ZodObject<{
        automatic_heating_enabled: z.ZodBoolean;
        automatic_cooling_enabled: z.ZodBoolean;
        hvac_mode_setting: z.ZodEnum<["off", "heat", "cool", "heat_cool"]>;
        cooling_set_point_celsius: z.ZodOptional<z.ZodNumber>;
        heating_set_point_celsius: z.ZodOptional<z.ZodNumber>;
        cooling_set_point_fahrenheit: z.ZodOptional<z.ZodNumber>;
        heating_set_point_fahrenheit: z.ZodOptional<z.ZodNumber>;
        manual_override_allowed: z.ZodBoolean;
    }, "strip", z.ZodTypeAny, {
        automatic_heating_enabled: boolean;
        automatic_cooling_enabled: boolean;
        hvac_mode_setting: "off" | "heat" | "cool" | "heat_cool";
        manual_override_allowed: boolean;
        cooling_set_point_celsius?: number | undefined;
        heating_set_point_celsius?: number | undefined;
        cooling_set_point_fahrenheit?: number | undefined;
        heating_set_point_fahrenheit?: number | undefined;
    }, {
        automatic_heating_enabled: boolean;
        automatic_cooling_enabled: boolean;
        hvac_mode_setting: "off" | "heat" | "cool" | "heat_cool";
        manual_override_allowed: boolean;
        cooling_set_point_celsius?: number | undefined;
        heating_set_point_celsius?: number | undefined;
        cooling_set_point_fahrenheit?: number | undefined;
        heating_set_point_fahrenheit?: number | undefined;
    }>>;
    default_climate_setting: z.ZodOptional<z.ZodOptional<z.ZodObject<{
        automatic_heating_enabled: z.ZodBoolean;
        automatic_cooling_enabled: z.ZodBoolean;
        hvac_mode_setting: z.ZodEnum<["off", "heat", "cool", "heat_cool"]>;
        cooling_set_point_celsius: z.ZodOptional<z.ZodNumber>;
        heating_set_point_celsius: z.ZodOptional<z.ZodNumber>;
        cooling_set_point_fahrenheit: z.ZodOptional<z.ZodNumber>;
        heating_set_point_fahrenheit: z.ZodOptional<z.ZodNumber>;
        manual_override_allowed: z.ZodBoolean;
    }, "strip", z.ZodTypeAny, {
        automatic_heating_enabled: boolean;
        automatic_cooling_enabled: boolean;
        hvac_mode_setting: "off" | "heat" | "cool" | "heat_cool";
        manual_override_allowed: boolean;
        cooling_set_point_celsius?: number | undefined;
        heating_set_point_celsius?: number | undefined;
        cooling_set_point_fahrenheit?: number | undefined;
        heating_set_point_fahrenheit?: number | undefined;
    }, {
        automatic_heating_enabled: boolean;
        automatic_cooling_enabled: boolean;
        hvac_mode_setting: "off" | "heat" | "cool" | "heat_cool";
        manual_override_allowed: boolean;
        cooling_set_point_celsius?: number | undefined;
        heating_set_point_celsius?: number | undefined;
        cooling_set_point_fahrenheit?: number | undefined;
        heating_set_point_fahrenheit?: number | undefined;
    }>>>;
    is_climate_setting_schedule_active: z.ZodOptional<z.ZodBoolean>;
    active_climate_setting_schedule: z.ZodOptional<z.ZodOptional<z.ZodObject<{
        name: z.ZodOptional<z.ZodString>;
        device_id: z.ZodString;
        created_at: z.ZodString;
        errors: z.ZodAny;
        climate_setting_schedule_id: z.ZodString;
        schedule_type: z.ZodLiteral<"time_bound">;
        schedule_starts_at: z.ZodString;
        schedule_ends_at: z.ZodString;
        automatic_heating_enabled: z.ZodOptional<z.ZodBoolean>;
        automatic_cooling_enabled: z.ZodOptional<z.ZodBoolean>;
        hvac_mode_setting: z.ZodOptional<z.ZodEnum<["off", "heat", "cool", "heat_cool"]>>;
        cooling_set_point_celsius: z.ZodOptional<z.ZodOptional<z.ZodNumber>>;
        heating_set_point_celsius: z.ZodOptional<z.ZodOptional<z.ZodNumber>>;
        cooling_set_point_fahrenheit: z.ZodOptional<z.ZodOptional<z.ZodNumber>>;
        heating_set_point_fahrenheit: z.ZodOptional<z.ZodOptional<z.ZodNumber>>;
        manual_override_allowed: z.ZodOptional<z.ZodBoolean>;
    }, "strip", z.ZodTypeAny, {
        device_id: string;
        created_at: string;
        climate_setting_schedule_id: string;
        schedule_type: "time_bound";
        schedule_starts_at: string;
        schedule_ends_at: string;
        name?: string | undefined;
        errors?: any;
        automatic_heating_enabled?: boolean | undefined;
        automatic_cooling_enabled?: boolean | undefined;
        hvac_mode_setting?: "off" | "heat" | "cool" | "heat_cool" | undefined;
        cooling_set_point_celsius?: number | undefined;
        heating_set_point_celsius?: number | undefined;
        cooling_set_point_fahrenheit?: number | undefined;
        heating_set_point_fahrenheit?: number | undefined;
        manual_override_allowed?: boolean | undefined;
    }, {
        device_id: string;
        created_at: string;
        climate_setting_schedule_id: string;
        schedule_type: "time_bound";
        schedule_starts_at: string;
        schedule_ends_at: string;
        name?: string | undefined;
        errors?: any;
        automatic_heating_enabled?: boolean | undefined;
        automatic_cooling_enabled?: boolean | undefined;
        hvac_mode_setting?: "off" | "heat" | "cool" | "heat_cool" | undefined;
        cooling_set_point_celsius?: number | undefined;
        heating_set_point_celsius?: number | undefined;
        cooling_set_point_fahrenheit?: number | undefined;
        heating_set_point_fahrenheit?: number | undefined;
        manual_override_allowed?: boolean | undefined;
    }>>>;
    min_cooling_set_point_celsius: z.ZodOptional<z.ZodNumber>;
    min_cooling_set_point_fahrenheit: z.ZodOptional<z.ZodNumber>;
    max_cooling_set_point_celsius: z.ZodOptional<z.ZodNumber>;
    max_cooling_set_point_fahrenheit: z.ZodOptional<z.ZodNumber>;
    is_cooling_available: z.ZodOptional<z.ZodLiteral<true>>;
}, "strip", z.ZodTypeAny, {
    temperature_fahrenheit?: number | undefined;
    temperature_celsius?: number | undefined;
    relative_humidity?: number | undefined;
    can_enable_automatic_heating?: boolean | undefined;
    can_enable_automatic_cooling?: boolean | undefined;
    available_hvac_mode_settings?: ("off" | "heat" | "cool" | "heat_cool")[] | undefined;
    is_heating_available?: false | undefined;
    is_heating?: boolean | undefined;
    is_cooling?: boolean | undefined;
    is_fan_running?: boolean | undefined;
    fan_mode_setting?: "auto" | "on" | undefined;
    is_temporary_manual_override_active?: boolean | undefined;
    current_climate_setting?: {
        automatic_heating_enabled: boolean;
        automatic_cooling_enabled: boolean;
        hvac_mode_setting: "off" | "heat" | "cool" | "heat_cool";
        manual_override_allowed: boolean;
        cooling_set_point_celsius?: number | undefined;
        heating_set_point_celsius?: number | undefined;
        cooling_set_point_fahrenheit?: number | undefined;
        heating_set_point_fahrenheit?: number | undefined;
    } | undefined;
    default_climate_setting?: {
        automatic_heating_enabled: boolean;
        automatic_cooling_enabled: boolean;
        hvac_mode_setting: "off" | "heat" | "cool" | "heat_cool";
        manual_override_allowed: boolean;
        cooling_set_point_celsius?: number | undefined;
        heating_set_point_celsius?: number | undefined;
        cooling_set_point_fahrenheit?: number | undefined;
        heating_set_point_fahrenheit?: number | undefined;
    } | undefined;
    is_climate_setting_schedule_active?: boolean | undefined;
    active_climate_setting_schedule?: {
        device_id: string;
        created_at: string;
        climate_setting_schedule_id: string;
        schedule_type: "time_bound";
        schedule_starts_at: string;
        schedule_ends_at: string;
        name?: string | undefined;
        errors?: any;
        automatic_heating_enabled?: boolean | undefined;
        automatic_cooling_enabled?: boolean | undefined;
        hvac_mode_setting?: "off" | "heat" | "cool" | "heat_cool" | undefined;
        cooling_set_point_celsius?: number | undefined;
        heating_set_point_celsius?: number | undefined;
        cooling_set_point_fahrenheit?: number | undefined;
        heating_set_point_fahrenheit?: number | undefined;
        manual_override_allowed?: boolean | undefined;
    } | undefined;
    min_cooling_set_point_celsius?: number | undefined;
    min_cooling_set_point_fahrenheit?: number | undefined;
    max_cooling_set_point_celsius?: number | undefined;
    max_cooling_set_point_fahrenheit?: number | undefined;
    is_cooling_available?: true | undefined;
}, {
    temperature_fahrenheit?: number | undefined;
    temperature_celsius?: number | undefined;
    relative_humidity?: number | undefined;
    can_enable_automatic_heating?: boolean | undefined;
    can_enable_automatic_cooling?: boolean | undefined;
    available_hvac_mode_settings?: ("off" | "heat" | "cool" | "heat_cool")[] | undefined;
    is_heating_available?: false | undefined;
    is_heating?: boolean | undefined;
    is_cooling?: boolean | undefined;
    is_fan_running?: boolean | undefined;
    fan_mode_setting?: "auto" | "on" | undefined;
    is_temporary_manual_override_active?: boolean | undefined;
    current_climate_setting?: {
        automatic_heating_enabled: boolean;
        automatic_cooling_enabled: boolean;
        hvac_mode_setting: "off" | "heat" | "cool" | "heat_cool";
        manual_override_allowed: boolean;
        cooling_set_point_celsius?: number | undefined;
        heating_set_point_celsius?: number | undefined;
        cooling_set_point_fahrenheit?: number | undefined;
        heating_set_point_fahrenheit?: number | undefined;
    } | undefined;
    default_climate_setting?: {
        automatic_heating_enabled: boolean;
        automatic_cooling_enabled: boolean;
        hvac_mode_setting: "off" | "heat" | "cool" | "heat_cool";
        manual_override_allowed: boolean;
        cooling_set_point_celsius?: number | undefined;
        heating_set_point_celsius?: number | undefined;
        cooling_set_point_fahrenheit?: number | undefined;
        heating_set_point_fahrenheit?: number | undefined;
    } | undefined;
    is_climate_setting_schedule_active?: boolean | undefined;
    active_climate_setting_schedule?: {
        device_id: string;
        created_at: string;
        climate_setting_schedule_id: string;
        schedule_type: "time_bound";
        schedule_starts_at: string;
        schedule_ends_at: string;
        name?: string | undefined;
        errors?: any;
        automatic_heating_enabled?: boolean | undefined;
        automatic_cooling_enabled?: boolean | undefined;
        hvac_mode_setting?: "off" | "heat" | "cool" | "heat_cool" | undefined;
        cooling_set_point_celsius?: number | undefined;
        heating_set_point_celsius?: number | undefined;
        cooling_set_point_fahrenheit?: number | undefined;
        heating_set_point_fahrenheit?: number | undefined;
        manual_override_allowed?: boolean | undefined;
    } | undefined;
    min_cooling_set_point_celsius?: number | undefined;
    min_cooling_set_point_fahrenheit?: number | undefined;
    max_cooling_set_point_celsius?: number | undefined;
    max_cooling_set_point_fahrenheit?: number | undefined;
    is_cooling_available?: true | undefined;
}>]>;
