import { z } from 'zod';
export declare const manufacturer_integration_support_level: z.ZodEnum<["stable", "beta", "planned", "unsupported", "inquire"]>;
export type ManufacturerIntegrationSupportLevel = z.infer<typeof manufacturer_integration_support_level>;
export declare const manufacturer_annotation_code: z.ZodEnum<["subscription_required"]>;
export type ManufacturerAnnotationCode = z.infer<typeof manufacturer_annotation_code>;
export declare const manufacturer_annotation: z.ZodObject<{
    annotation_code: z.ZodEnum<["subscription_required"]>;
    message: z.ZodString;
}, "strip", z.ZodTypeAny, {
    message: string;
    annotation_code: "subscription_required";
}, {
    message: string;
    annotation_code: "subscription_required";
}>;
export type ManufacturerAnnotation = z.infer<typeof manufacturer_annotation>;
export declare const manufacturer: z.ZodObject<{
    manufacturer_id: z.ZodString;
    display_name: z.ZodString;
    logo: z.ZodOptional<z.ZodObject<{
        url: z.ZodString;
        width: z.ZodNumber;
        height: z.ZodNumber;
    }, "strip", z.ZodTypeAny, {
        height: number;
        width: number;
        url: string;
    }, {
        height: number;
        width: number;
        url: string;
    }>>;
    /** @deprecated */
    integration: z.ZodEnum<["stable", "beta", "planned", "unsupported", "inquire"]>;
    integration_support_level: z.ZodEnum<["stable", "beta", "planned", "unsupported", "inquire"]>;
    is_connect_webview_supported: z.ZodBoolean;
    requires_seam_support_to_add_account: z.ZodBoolean;
    device_model_count: z.ZodNumber;
    annotations: z.ZodArray<z.ZodObject<{
        annotation_code: z.ZodEnum<["subscription_required"]>;
        message: z.ZodString;
    }, "strip", z.ZodTypeAny, {
        message: string;
        annotation_code: "subscription_required";
    }, {
        message: string;
        annotation_code: "subscription_required";
    }>, "many">;
    website: z.ZodOptional<z.ZodString>;
    legal_name: z.ZodOptional<z.ZodString>;
    parent_organization: z.ZodOptional<z.ZodString>;
    headquarters: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
    countries_of_origin: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
    founding_year: z.ZodOptional<z.ZodString>;
    us_customer_support_tel: z.ZodOptional<z.ZodString>;
    us_customer_support_email: z.ZodOptional<z.ZodString>;
    us_customer_support_contact_url: z.ZodOptional<z.ZodString>;
    seam_api_guide: z.ZodOptional<z.ZodString>;
    description: z.ZodOptional<z.ZodString>;
}, "strip", z.ZodTypeAny, {
    display_name: string;
    manufacturer_id: string;
    integration: "beta" | "stable" | "planned" | "unsupported" | "inquire";
    integration_support_level: "beta" | "stable" | "planned" | "unsupported" | "inquire";
    is_connect_webview_supported: boolean;
    requires_seam_support_to_add_account: boolean;
    device_model_count: number;
    annotations: {
        message: string;
        annotation_code: "subscription_required";
    }[];
    logo?: {
        height: number;
        width: number;
        url: string;
    } | undefined;
    website?: string | undefined;
    legal_name?: string | undefined;
    parent_organization?: string | undefined;
    headquarters?: string[] | undefined;
    countries_of_origin?: string[] | undefined;
    founding_year?: string | undefined;
    us_customer_support_tel?: string | undefined;
    us_customer_support_email?: string | undefined;
    us_customer_support_contact_url?: string | undefined;
    seam_api_guide?: string | undefined;
    description?: string | undefined;
}, {
    display_name: string;
    manufacturer_id: string;
    integration: "beta" | "stable" | "planned" | "unsupported" | "inquire";
    integration_support_level: "beta" | "stable" | "planned" | "unsupported" | "inquire";
    is_connect_webview_supported: boolean;
    requires_seam_support_to_add_account: boolean;
    device_model_count: number;
    annotations: {
        message: string;
        annotation_code: "subscription_required";
    }[];
    logo?: {
        height: number;
        width: number;
        url: string;
    } | undefined;
    website?: string | undefined;
    legal_name?: string | undefined;
    parent_organization?: string | undefined;
    headquarters?: string[] | undefined;
    countries_of_origin?: string[] | undefined;
    founding_year?: string | undefined;
    us_customer_support_tel?: string | undefined;
    us_customer_support_email?: string | undefined;
    us_customer_support_contact_url?: string | undefined;
    seam_api_guide?: string | undefined;
    description?: string | undefined;
}>;
export type Manufacturer = z.infer<typeof manufacturer>;
