import { z } from 'zod';
export declare const routes: {
    readonly '/api/v1/device_models/get': {
        readonly auth: "publishable_key";
        readonly methods: readonly ["GET", "OPTIONS"];
        readonly queryParams: z.ZodObject<{
            device_model_id: z.ZodString;
        }, "strip", z.ZodTypeAny, {
            device_model_id: string;
        }, {
            device_model_id: string;
        }>;
        readonly jsonResponse: z.ZodObject<{
            device_model: z.ZodIntersection<z.ZodObject<{
                device_model_id: z.ZodString;
                manufacturer: z.ZodObject<Omit<{
                    manufacturer_id: z.ZodString;
                    display_name: z.ZodString;
                    logo: z.ZodOptional<z.ZodObject<{
                        url: z.ZodString;
                        width: z.ZodNumber;
                        height: z.ZodNumber;
                    }, "strip", z.ZodTypeAny, {
                        height: number;
                        width: number;
                        url: string;
                    }, {
                        height: number;
                        width: number;
                        url: string;
                    }>>;
                    integration: z.ZodEnum<["stable", "beta", "planned", "unsupported", "inquire"]>;
                    integration_support_level: z.ZodEnum<["stable", "beta", "planned", "unsupported", "inquire"]>;
                    is_connect_webview_supported: z.ZodBoolean;
                    requires_seam_support_to_add_account: z.ZodBoolean;
                    device_model_count: z.ZodNumber;
                    annotations: z.ZodArray<z.ZodObject<{
                        annotation_code: z.ZodEnum<["subscription_required"]>;
                        message: z.ZodString;
                    }, "strip", z.ZodTypeAny, {
                        message: string;
                        annotation_code: "subscription_required";
                    }, {
                        message: string;
                        annotation_code: "subscription_required";
                    }>, "many">;
                    website: z.ZodOptional<z.ZodString>;
                    legal_name: z.ZodOptional<z.ZodString>;
                    parent_organization: z.ZodOptional<z.ZodString>;
                    headquarters: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                    countries_of_origin: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                    founding_year: z.ZodOptional<z.ZodString>;
                    us_customer_support_tel: z.ZodOptional<z.ZodString>;
                    us_customer_support_email: z.ZodOptional<z.ZodString>;
                    /** @deprecated */
                    us_customer_support_contact_url: z.ZodOptional<z.ZodString>;
                    seam_api_guide: z.ZodOptional<z.ZodString>;
                    description: z.ZodOptional<z.ZodString>;
                }, "device_model_count">, "strip", z.ZodTypeAny, {
                    display_name: string;
                    manufacturer_id: string;
                    integration: "beta" | "stable" | "planned" | "unsupported" | "inquire";
                    integration_support_level: "beta" | "stable" | "planned" | "unsupported" | "inquire";
                    is_connect_webview_supported: boolean;
                    requires_seam_support_to_add_account: boolean;
                    annotations: {
                        message: string;
                        annotation_code: "subscription_required";
                    }[];
                    description?: string | undefined;
                    logo?: {
                        height: number;
                        width: number;
                        url: string;
                    } | undefined;
                    website?: string | undefined;
                    legal_name?: string | undefined;
                    parent_organization?: string | undefined;
                    headquarters?: string[] | undefined;
                    countries_of_origin?: string[] | undefined;
                    founding_year?: string | undefined;
                    us_customer_support_tel?: string | undefined;
                    us_customer_support_email?: string | undefined;
                    us_customer_support_contact_url?: string | undefined;
                    seam_api_guide?: string | undefined;
                }, {
                    display_name: string;
                    manufacturer_id: string;
                    integration: "beta" | "stable" | "planned" | "unsupported" | "inquire";
                    integration_support_level: "beta" | "stable" | "planned" | "unsupported" | "inquire";
                    is_connect_webview_supported: boolean;
                    requires_seam_support_to_add_account: boolean;
                    annotations: {
                        message: string;
                        annotation_code: "subscription_required";
                    }[];
                    description?: string | undefined;
                    logo?: {
                        height: number;
                        width: number;
                        url: string;
                    } | undefined;
                    website?: string | undefined;
                    legal_name?: string | undefined;
                    parent_organization?: string | undefined;
                    headquarters?: string[] | undefined;
                    countries_of_origin?: string[] | undefined;
                    founding_year?: string | undefined;
                    us_customer_support_tel?: string | undefined;
                    us_customer_support_email?: string | undefined;
                    us_customer_support_contact_url?: string | undefined;
                    seam_api_guide?: string | undefined;
                }>;
                is_device_supported: z.ZodBoolean;
                display_name: z.ZodString;
                description: z.ZodString;
                product_url: z.ZodOptional<z.ZodString>;
                main_connection_type: z.ZodEnum<["wifi", "zwave", "zigbee", "unknown"]>;
                hardware: z.ZodObject<{
                    has_physical_key: z.ZodOptional<z.ZodBoolean>;
                }, "strip", z.ZodTypeAny, {
                    has_physical_key?: boolean | undefined;
                }, {
                    has_physical_key?: boolean | undefined;
                }>;
                aesthetic_variants: z.ZodArray<z.ZodObject<{
                    slug: z.ZodString;
                    display_name: z.ZodString;
                    primary_color_hex: z.ZodOptional<z.ZodString>;
                    manufacturer_sku: z.ZodOptional<z.ZodString>;
                    front_image: z.ZodOptional<z.ZodObject<{
                        url: z.ZodString;
                        width: z.ZodNumber;
                        height: z.ZodNumber;
                    }, "strip", z.ZodTypeAny, {
                        height: number;
                        width: number;
                        url: string;
                    }, {
                        height: number;
                        width: number;
                        url: string;
                    }>>;
                    back_image: z.ZodOptional<z.ZodObject<{
                        url: z.ZodString;
                        width: z.ZodNumber;
                        height: z.ZodNumber;
                    }, "strip", z.ZodTypeAny, {
                        height: number;
                        width: number;
                        url: string;
                    }, {
                        height: number;
                        width: number;
                        url: string;
                    }>>;
                    images: z.ZodArray<z.ZodObject<{
                        url: z.ZodString;
                        width: z.ZodNumber;
                        height: z.ZodNumber;
                    }, "strip", z.ZodTypeAny, {
                        height: number;
                        width: number;
                        url: string;
                    }, {
                        height: number;
                        width: number;
                        url: string;
                    }>, "many">;
                }, "strip", z.ZodTypeAny, {
                    display_name: string;
                    slug: string;
                    images: {
                        height: number;
                        width: number;
                        url: string;
                    }[];
                    primary_color_hex?: string | undefined;
                    manufacturer_sku?: string | undefined;
                    front_image?: {
                        height: number;
                        width: number;
                        url: string;
                    } | undefined;
                    back_image?: {
                        height: number;
                        width: number;
                        url: string;
                    } | undefined;
                }, {
                    display_name: string;
                    slug: string;
                    images: {
                        height: number;
                        width: number;
                        url: string;
                    }[];
                    primary_color_hex?: string | undefined;
                    manufacturer_sku?: string | undefined;
                    front_image?: {
                        height: number;
                        width: number;
                        url: string;
                    } | undefined;
                    back_image?: {
                        height: number;
                        width: number;
                        url: string;
                    } | undefined;
                }>, "many">;
                power_sources: z.ZodArray<z.ZodEnum<["battery", "hardwired", "mechanical_harvesting", "wireless", "ethernet"]>, "many">;
            }, "strip", z.ZodTypeAny, {
                description: string;
                display_name: string;
                device_model_id: string;
                manufacturer: {
                    display_name: string;
                    manufacturer_id: string;
                    integration: "beta" | "stable" | "planned" | "unsupported" | "inquire";
                    integration_support_level: "beta" | "stable" | "planned" | "unsupported" | "inquire";
                    is_connect_webview_supported: boolean;
                    requires_seam_support_to_add_account: boolean;
                    annotations: {
                        message: string;
                        annotation_code: "subscription_required";
                    }[];
                    description?: string | undefined;
                    logo?: {
                        height: number;
                        width: number;
                        url: string;
                    } | undefined;
                    website?: string | undefined;
                    legal_name?: string | undefined;
                    parent_organization?: string | undefined;
                    headquarters?: string[] | undefined;
                    countries_of_origin?: string[] | undefined;
                    founding_year?: string | undefined;
                    us_customer_support_tel?: string | undefined;
                    us_customer_support_email?: string | undefined;
                    us_customer_support_contact_url?: string | undefined;
                    seam_api_guide?: string | undefined;
                };
                is_device_supported: boolean;
                main_connection_type: "unknown" | "wifi" | "zwave" | "zigbee";
                hardware: {
                    has_physical_key?: boolean | undefined;
                };
                aesthetic_variants: {
                    display_name: string;
                    slug: string;
                    images: {
                        height: number;
                        width: number;
                        url: string;
                    }[];
                    primary_color_hex?: string | undefined;
                    manufacturer_sku?: string | undefined;
                    front_image?: {
                        height: number;
                        width: number;
                        url: string;
                    } | undefined;
                    back_image?: {
                        height: number;
                        width: number;
                        url: string;
                    } | undefined;
                }[];
                power_sources: ("battery" | "hardwired" | "mechanical_harvesting" | "wireless" | "ethernet")[];
                product_url?: string | undefined;
            }, {
                description: string;
                display_name: string;
                device_model_id: string;
                manufacturer: {
                    display_name: string;
                    manufacturer_id: string;
                    integration: "beta" | "stable" | "planned" | "unsupported" | "inquire";
                    integration_support_level: "beta" | "stable" | "planned" | "unsupported" | "inquire";
                    is_connect_webview_supported: boolean;
                    requires_seam_support_to_add_account: boolean;
                    annotations: {
                        message: string;
                        annotation_code: "subscription_required";
                    }[];
                    description?: string | undefined;
                    logo?: {
                        height: number;
                        width: number;
                        url: string;
                    } | undefined;
                    website?: string | undefined;
                    legal_name?: string | undefined;
                    parent_organization?: string | undefined;
                    headquarters?: string[] | undefined;
                    countries_of_origin?: string[] | undefined;
                    founding_year?: string | undefined;
                    us_customer_support_tel?: string | undefined;
                    us_customer_support_email?: string | undefined;
                    us_customer_support_contact_url?: string | undefined;
                    seam_api_guide?: string | undefined;
                };
                is_device_supported: boolean;
                main_connection_type: "unknown" | "wifi" | "zwave" | "zigbee";
                hardware: {
                    has_physical_key?: boolean | undefined;
                };
                aesthetic_variants: {
                    display_name: string;
                    slug: string;
                    images: {
                        height: number;
                        width: number;
                        url: string;
                    }[];
                    primary_color_hex?: string | undefined;
                    manufacturer_sku?: string | undefined;
                    front_image?: {
                        height: number;
                        width: number;
                        url: string;
                    } | undefined;
                    back_image?: {
                        height: number;
                        width: number;
                        url: string;
                    } | undefined;
                }[];
                power_sources: ("battery" | "hardwired" | "mechanical_harvesting" | "wireless" | "ethernet")[];
                product_url?: string | undefined;
            }>, z.ZodDiscriminatedUnion<"main_category", [z.ZodObject<{
                main_category: z.ZodLiteral<"smartlock">;
                physical_properties: z.ZodObject<{
                    lock_type: z.ZodEnum<["deadbolt", "lever", "mortise", "lockbox", "cylinder", "padlock", "locker", "unknown"]>;
                    has_physical_key: z.ZodBoolean;
                    has_camera: z.ZodBoolean;
                }, "strip", z.ZodTypeAny, {
                    lock_type: "unknown" | "deadbolt" | "lever" | "mortise" | "lockbox" | "cylinder" | "padlock" | "locker";
                    has_physical_key: boolean;
                    has_camera: boolean;
                }, {
                    lock_type: "unknown" | "deadbolt" | "lever" | "mortise" | "lockbox" | "cylinder" | "padlock" | "locker";
                    has_physical_key: boolean;
                    has_camera: boolean;
                }>;
                software_features: z.ZodObject<{
                    can_remotely_unlock: z.ZodBoolean;
                    can_program_access_codes: z.ZodBoolean;
                    can_program_access_schedules: z.ZodBoolean;
                    can_program_access_codes_offline: z.ZodBoolean;
                }, "strip", z.ZodTypeAny, {
                    can_remotely_unlock: boolean;
                    can_program_access_codes: boolean;
                    can_program_access_schedules: boolean;
                    can_program_access_codes_offline: boolean;
                }, {
                    can_remotely_unlock: boolean;
                    can_program_access_codes: boolean;
                    can_program_access_schedules: boolean;
                    can_program_access_codes_offline: boolean;
                }>;
                can_remotely_unlock: z.ZodOptional<z.ZodLiteral<true>>;
                can_remotely_lock: z.ZodOptional<z.ZodLiteral<true>>;
                can_program_offline_access_codes: z.ZodOptional<z.ZodLiteral<true>>;
                can_program_online_access_codes: z.ZodOptional<z.ZodLiteral<true>>;
            }, "strip", z.ZodTypeAny, {
                main_category: "smartlock";
                physical_properties: {
                    lock_type: "unknown" | "deadbolt" | "lever" | "mortise" | "lockbox" | "cylinder" | "padlock" | "locker";
                    has_physical_key: boolean;
                    has_camera: boolean;
                };
                software_features: {
                    can_remotely_unlock: boolean;
                    can_program_access_codes: boolean;
                    can_program_access_schedules: boolean;
                    can_program_access_codes_offline: boolean;
                };
                can_remotely_unlock?: true | undefined;
                can_remotely_lock?: true | undefined;
                can_program_offline_access_codes?: true | undefined;
                can_program_online_access_codes?: true | undefined;
            }, {
                main_category: "smartlock";
                physical_properties: {
                    lock_type: "unknown" | "deadbolt" | "lever" | "mortise" | "lockbox" | "cylinder" | "padlock" | "locker";
                    has_physical_key: boolean;
                    has_camera: boolean;
                };
                software_features: {
                    can_remotely_unlock: boolean;
                    can_program_access_codes: boolean;
                    can_program_access_schedules: boolean;
                    can_program_access_codes_offline: boolean;
                };
                can_remotely_unlock?: true | undefined;
                can_remotely_lock?: true | undefined;
                can_program_offline_access_codes?: true | undefined;
                can_program_online_access_codes?: true | undefined;
            }>, z.ZodObject<{
                main_category: z.ZodLiteral<"sensor">;
                physical_properties: z.ZodObject<{
                    has_noise_sensor: z.ZodBoolean;
                    has_humidity_sensor: z.ZodBoolean;
                    has_temperature_sensor: z.ZodBoolean;
                    has_occupancy_detection: z.ZodBoolean;
                }, "strip", z.ZodTypeAny, {
                    has_noise_sensor: boolean;
                    has_humidity_sensor: boolean;
                    has_temperature_sensor: boolean;
                    has_occupancy_detection: boolean;
                }, {
                    has_noise_sensor: boolean;
                    has_humidity_sensor: boolean;
                    has_temperature_sensor: boolean;
                    has_occupancy_detection: boolean;
                }>;
            }, "strip", z.ZodTypeAny, {
                main_category: "sensor";
                physical_properties: {
                    has_noise_sensor: boolean;
                    has_humidity_sensor: boolean;
                    has_temperature_sensor: boolean;
                    has_occupancy_detection: boolean;
                };
            }, {
                main_category: "sensor";
                physical_properties: {
                    has_noise_sensor: boolean;
                    has_humidity_sensor: boolean;
                    has_temperature_sensor: boolean;
                    has_occupancy_detection: boolean;
                };
            }>, z.ZodObject<{
                main_category: z.ZodLiteral<"thermostat">;
                physical_properties: z.ZodObject<{
                    available_modes: z.ZodArray<z.ZodEnum<["heat", "cool", "fan", "eco"]>, "many">;
                    is_heat_pump_compatible: z.ZodBoolean;
                    has_occupancy_detection: z.ZodBoolean;
                    supports_demand_response: z.ZodBoolean;
                    has_humidity_sensor: z.ZodBoolean;
                    has_temperature_sensor: z.ZodBoolean;
                    supports_emergency_heating_mode: z.ZodBoolean;
                }, "strip", z.ZodTypeAny, {
                    has_humidity_sensor: boolean;
                    has_temperature_sensor: boolean;
                    has_occupancy_detection: boolean;
                    available_modes: ("heat" | "cool" | "fan" | "eco")[];
                    is_heat_pump_compatible: boolean;
                    supports_demand_response: boolean;
                    supports_emergency_heating_mode: boolean;
                }, {
                    has_humidity_sensor: boolean;
                    has_temperature_sensor: boolean;
                    has_occupancy_detection: boolean;
                    available_modes: ("heat" | "cool" | "fan" | "eco")[];
                    is_heat_pump_compatible: boolean;
                    supports_demand_response: boolean;
                    supports_emergency_heating_mode: boolean;
                }>;
                software_features: z.ZodObject<{
                    can_program_climate_schedules: z.ZodBoolean;
                }, "strip", z.ZodTypeAny, {
                    can_program_climate_schedules: boolean;
                }, {
                    can_program_climate_schedules: boolean;
                }>;
            }, "strip", z.ZodTypeAny, {
                main_category: "thermostat";
                physical_properties: {
                    has_humidity_sensor: boolean;
                    has_temperature_sensor: boolean;
                    has_occupancy_detection: boolean;
                    available_modes: ("heat" | "cool" | "fan" | "eco")[];
                    is_heat_pump_compatible: boolean;
                    supports_demand_response: boolean;
                    supports_emergency_heating_mode: boolean;
                };
                software_features: {
                    can_program_climate_schedules: boolean;
                };
            }, {
                main_category: "thermostat";
                physical_properties: {
                    has_humidity_sensor: boolean;
                    has_temperature_sensor: boolean;
                    has_occupancy_detection: boolean;
                    available_modes: ("heat" | "cool" | "fan" | "eco")[];
                    is_heat_pump_compatible: boolean;
                    supports_demand_response: boolean;
                    supports_emergency_heating_mode: boolean;
                };
                software_features: {
                    can_program_climate_schedules: boolean;
                };
            }>, z.ZodObject<{
                main_category: z.ZodLiteral<"relay">;
            }, "strip", z.ZodTypeAny, {
                main_category: "relay";
            }, {
                main_category: "relay";
            }>, z.ZodObject<{
                main_category: z.ZodLiteral<"intercom">;
                physical_properties: z.ZodObject<{
                    has_camera: z.ZodBoolean;
                    has_rfid_reader: z.ZodDefault<z.ZodBoolean>;
                    has_nfc_reader: z.ZodDefault<z.ZodBoolean>;
                    has_wiegand_interface: z.ZodDefault<z.ZodBoolean>;
                }, "strip", z.ZodTypeAny, {
                    has_camera: boolean;
                    has_rfid_reader: boolean;
                    has_nfc_reader: boolean;
                    has_wiegand_interface: boolean;
                }, {
                    has_camera: boolean;
                    has_rfid_reader?: boolean | undefined;
                    has_nfc_reader?: boolean | undefined;
                    has_wiegand_interface?: boolean | undefined;
                }>;
                software_features: z.ZodObject<{
                    can_remotely_unlock: z.ZodBoolean;
                    can_program_access_codes: z.ZodBoolean;
                    can_unlock_with_face_recognition: z.ZodDefault<z.ZodBoolean>;
                    supports_onvif: z.ZodDefault<z.ZodBoolean>;
                }, "strip", z.ZodTypeAny, {
                    can_remotely_unlock: boolean;
                    can_program_access_codes: boolean;
                    can_unlock_with_face_recognition: boolean;
                    supports_onvif: boolean;
                }, {
                    can_remotely_unlock: boolean;
                    can_program_access_codes: boolean;
                    can_unlock_with_face_recognition?: boolean | undefined;
                    supports_onvif?: boolean | undefined;
                }>;
            }, "strip", z.ZodTypeAny, {
                main_category: "intercom";
                physical_properties: {
                    has_camera: boolean;
                    has_rfid_reader: boolean;
                    has_nfc_reader: boolean;
                    has_wiegand_interface: boolean;
                };
                software_features: {
                    can_remotely_unlock: boolean;
                    can_program_access_codes: boolean;
                    can_unlock_with_face_recognition: boolean;
                    supports_onvif: boolean;
                };
            }, {
                main_category: "intercom";
                physical_properties: {
                    has_camera: boolean;
                    has_rfid_reader?: boolean | undefined;
                    has_nfc_reader?: boolean | undefined;
                    has_wiegand_interface?: boolean | undefined;
                };
                software_features: {
                    can_remotely_unlock: boolean;
                    can_program_access_codes: boolean;
                    can_unlock_with_face_recognition?: boolean | undefined;
                    supports_onvif?: boolean | undefined;
                };
            }>, z.ZodObject<{
                main_category: z.ZodLiteral<"accessory">;
            }, "strip", z.ZodTypeAny, {
                main_category: "accessory";
            }, {
                main_category: "accessory";
            }>]>>;
        }, "strip", z.ZodTypeAny, {
            device_model: ({
                description: string;
                display_name: string;
                device_model_id: string;
                manufacturer: {
                    display_name: string;
                    manufacturer_id: string;
                    integration: "beta" | "stable" | "planned" | "unsupported" | "inquire";
                    integration_support_level: "beta" | "stable" | "planned" | "unsupported" | "inquire";
                    is_connect_webview_supported: boolean;
                    requires_seam_support_to_add_account: boolean;
                    annotations: {
                        message: string;
                        annotation_code: "subscription_required";
                    }[];
                    description?: string | undefined;
                    logo?: {
                        height: number;
                        width: number;
                        url: string;
                    } | undefined;
                    website?: string | undefined;
                    legal_name?: string | undefined;
                    parent_organization?: string | undefined;
                    headquarters?: string[] | undefined;
                    countries_of_origin?: string[] | undefined;
                    founding_year?: string | undefined;
                    us_customer_support_tel?: string | undefined;
                    us_customer_support_email?: string | undefined;
                    us_customer_support_contact_url?: string | undefined;
                    seam_api_guide?: string | undefined;
                };
                is_device_supported: boolean;
                main_connection_type: "unknown" | "wifi" | "zwave" | "zigbee";
                hardware: {
                    has_physical_key?: boolean | undefined;
                };
                aesthetic_variants: {
                    display_name: string;
                    slug: string;
                    images: {
                        height: number;
                        width: number;
                        url: string;
                    }[];
                    primary_color_hex?: string | undefined;
                    manufacturer_sku?: string | undefined;
                    front_image?: {
                        height: number;
                        width: number;
                        url: string;
                    } | undefined;
                    back_image?: {
                        height: number;
                        width: number;
                        url: string;
                    } | undefined;
                }[];
                power_sources: ("battery" | "hardwired" | "mechanical_harvesting" | "wireless" | "ethernet")[];
                product_url?: string | undefined;
            } & {
                main_category: "smartlock";
                physical_properties: {
                    lock_type: "unknown" | "deadbolt" | "lever" | "mortise" | "lockbox" | "cylinder" | "padlock" | "locker";
                    has_physical_key: boolean;
                    has_camera: boolean;
                };
                software_features: {
                    can_remotely_unlock: boolean;
                    can_program_access_codes: boolean;
                    can_program_access_schedules: boolean;
                    can_program_access_codes_offline: boolean;
                };
                can_remotely_unlock?: true | undefined;
                can_remotely_lock?: true | undefined;
                can_program_offline_access_codes?: true | undefined;
                can_program_online_access_codes?: true | undefined;
            }) | ({
                description: string;
                display_name: string;
                device_model_id: string;
                manufacturer: {
                    display_name: string;
                    manufacturer_id: string;
                    integration: "beta" | "stable" | "planned" | "unsupported" | "inquire";
                    integration_support_level: "beta" | "stable" | "planned" | "unsupported" | "inquire";
                    is_connect_webview_supported: boolean;
                    requires_seam_support_to_add_account: boolean;
                    annotations: {
                        message: string;
                        annotation_code: "subscription_required";
                    }[];
                    description?: string | undefined;
                    logo?: {
                        height: number;
                        width: number;
                        url: string;
                    } | undefined;
                    website?: string | undefined;
                    legal_name?: string | undefined;
                    parent_organization?: string | undefined;
                    headquarters?: string[] | undefined;
                    countries_of_origin?: string[] | undefined;
                    founding_year?: string | undefined;
                    us_customer_support_tel?: string | undefined;
                    us_customer_support_email?: string | undefined;
                    us_customer_support_contact_url?: string | undefined;
                    seam_api_guide?: string | undefined;
                };
                is_device_supported: boolean;
                main_connection_type: "unknown" | "wifi" | "zwave" | "zigbee";
                hardware: {
                    has_physical_key?: boolean | undefined;
                };
                aesthetic_variants: {
                    display_name: string;
                    slug: string;
                    images: {
                        height: number;
                        width: number;
                        url: string;
                    }[];
                    primary_color_hex?: string | undefined;
                    manufacturer_sku?: string | undefined;
                    front_image?: {
                        height: number;
                        width: number;
                        url: string;
                    } | undefined;
                    back_image?: {
                        height: number;
                        width: number;
                        url: string;
                    } | undefined;
                }[];
                power_sources: ("battery" | "hardwired" | "mechanical_harvesting" | "wireless" | "ethernet")[];
                product_url?: string | undefined;
            } & {
                main_category: "sensor";
                physical_properties: {
                    has_noise_sensor: boolean;
                    has_humidity_sensor: boolean;
                    has_temperature_sensor: boolean;
                    has_occupancy_detection: boolean;
                };
            }) | ({
                description: string;
                display_name: string;
                device_model_id: string;
                manufacturer: {
                    display_name: string;
                    manufacturer_id: string;
                    integration: "beta" | "stable" | "planned" | "unsupported" | "inquire";
                    integration_support_level: "beta" | "stable" | "planned" | "unsupported" | "inquire";
                    is_connect_webview_supported: boolean;
                    requires_seam_support_to_add_account: boolean;
                    annotations: {
                        message: string;
                        annotation_code: "subscription_required";
                    }[];
                    description?: string | undefined;
                    logo?: {
                        height: number;
                        width: number;
                        url: string;
                    } | undefined;
                    website?: string | undefined;
                    legal_name?: string | undefined;
                    parent_organization?: string | undefined;
                    headquarters?: string[] | undefined;
                    countries_of_origin?: string[] | undefined;
                    founding_year?: string | undefined;
                    us_customer_support_tel?: string | undefined;
                    us_customer_support_email?: string | undefined;
                    us_customer_support_contact_url?: string | undefined;
                    seam_api_guide?: string | undefined;
                };
                is_device_supported: boolean;
                main_connection_type: "unknown" | "wifi" | "zwave" | "zigbee";
                hardware: {
                    has_physical_key?: boolean | undefined;
                };
                aesthetic_variants: {
                    display_name: string;
                    slug: string;
                    images: {
                        height: number;
                        width: number;
                        url: string;
                    }[];
                    primary_color_hex?: string | undefined;
                    manufacturer_sku?: string | undefined;
                    front_image?: {
                        height: number;
                        width: number;
                        url: string;
                    } | undefined;
                    back_image?: {
                        height: number;
                        width: number;
                        url: string;
                    } | undefined;
                }[];
                power_sources: ("battery" | "hardwired" | "mechanical_harvesting" | "wireless" | "ethernet")[];
                product_url?: string | undefined;
            } & {
                main_category: "thermostat";
                physical_properties: {
                    has_humidity_sensor: boolean;
                    has_temperature_sensor: boolean;
                    has_occupancy_detection: boolean;
                    available_modes: ("heat" | "cool" | "fan" | "eco")[];
                    is_heat_pump_compatible: boolean;
                    supports_demand_response: boolean;
                    supports_emergency_heating_mode: boolean;
                };
                software_features: {
                    can_program_climate_schedules: boolean;
                };
            }) | ({
                description: string;
                display_name: string;
                device_model_id: string;
                manufacturer: {
                    display_name: string;
                    manufacturer_id: string;
                    integration: "beta" | "stable" | "planned" | "unsupported" | "inquire";
                    integration_support_level: "beta" | "stable" | "planned" | "unsupported" | "inquire";
                    is_connect_webview_supported: boolean;
                    requires_seam_support_to_add_account: boolean;
                    annotations: {
                        message: string;
                        annotation_code: "subscription_required";
                    }[];
                    description?: string | undefined;
                    logo?: {
                        height: number;
                        width: number;
                        url: string;
                    } | undefined;
                    website?: string | undefined;
                    legal_name?: string | undefined;
                    parent_organization?: string | undefined;
                    headquarters?: string[] | undefined;
                    countries_of_origin?: string[] | undefined;
                    founding_year?: string | undefined;
                    us_customer_support_tel?: string | undefined;
                    us_customer_support_email?: string | undefined;
                    us_customer_support_contact_url?: string | undefined;
                    seam_api_guide?: string | undefined;
                };
                is_device_supported: boolean;
                main_connection_type: "unknown" | "wifi" | "zwave" | "zigbee";
                hardware: {
                    has_physical_key?: boolean | undefined;
                };
                aesthetic_variants: {
                    display_name: string;
                    slug: string;
                    images: {
                        height: number;
                        width: number;
                        url: string;
                    }[];
                    primary_color_hex?: string | undefined;
                    manufacturer_sku?: string | undefined;
                    front_image?: {
                        height: number;
                        width: number;
                        url: string;
                    } | undefined;
                    back_image?: {
                        height: number;
                        width: number;
                        url: string;
                    } | undefined;
                }[];
                power_sources: ("battery" | "hardwired" | "mechanical_harvesting" | "wireless" | "ethernet")[];
                product_url?: string | undefined;
            } & {
                main_category: "relay";
            }) | ({
                description: string;
                display_name: string;
                device_model_id: string;
                manufacturer: {
                    display_name: string;
                    manufacturer_id: string;
                    integration: "beta" | "stable" | "planned" | "unsupported" | "inquire";
                    integration_support_level: "beta" | "stable" | "planned" | "unsupported" | "inquire";
                    is_connect_webview_supported: boolean;
                    requires_seam_support_to_add_account: boolean;
                    annotations: {
                        message: string;
                        annotation_code: "subscription_required";
                    }[];
                    description?: string | undefined;
                    logo?: {
                        height: number;
                        width: number;
                        url: string;
                    } | undefined;
                    website?: string | undefined;
                    legal_name?: string | undefined;
                    parent_organization?: string | undefined;
                    headquarters?: string[] | undefined;
                    countries_of_origin?: string[] | undefined;
                    founding_year?: string | undefined;
                    us_customer_support_tel?: string | undefined;
                    us_customer_support_email?: string | undefined;
                    us_customer_support_contact_url?: string | undefined;
                    seam_api_guide?: string | undefined;
                };
                is_device_supported: boolean;
                main_connection_type: "unknown" | "wifi" | "zwave" | "zigbee";
                hardware: {
                    has_physical_key?: boolean | undefined;
                };
                aesthetic_variants: {
                    display_name: string;
                    slug: string;
                    images: {
                        height: number;
                        width: number;
                        url: string;
                    }[];
                    primary_color_hex?: string | undefined;
                    manufacturer_sku?: string | undefined;
                    front_image?: {
                        height: number;
                        width: number;
                        url: string;
                    } | undefined;
                    back_image?: {
                        height: number;
                        width: number;
                        url: string;
                    } | undefined;
                }[];
                power_sources: ("battery" | "hardwired" | "mechanical_harvesting" | "wireless" | "ethernet")[];
                product_url?: string | undefined;
            } & {
                main_category: "intercom";
                physical_properties: {
                    has_camera: boolean;
                    has_rfid_reader: boolean;
                    has_nfc_reader: boolean;
                    has_wiegand_interface: boolean;
                };
                software_features: {
                    can_remotely_unlock: boolean;
                    can_program_access_codes: boolean;
                    can_unlock_with_face_recognition: boolean;
                    supports_onvif: boolean;
                };
            }) | ({
                description: string;
                display_name: string;
                device_model_id: string;
                manufacturer: {
                    display_name: string;
                    manufacturer_id: string;
                    integration: "beta" | "stable" | "planned" | "unsupported" | "inquire";
                    integration_support_level: "beta" | "stable" | "planned" | "unsupported" | "inquire";
                    is_connect_webview_supported: boolean;
                    requires_seam_support_to_add_account: boolean;
                    annotations: {
                        message: string;
                        annotation_code: "subscription_required";
                    }[];
                    description?: string | undefined;
                    logo?: {
                        height: number;
                        width: number;
                        url: string;
                    } | undefined;
                    website?: string | undefined;
                    legal_name?: string | undefined;
                    parent_organization?: string | undefined;
                    headquarters?: string[] | undefined;
                    countries_of_origin?: string[] | undefined;
                    founding_year?: string | undefined;
                    us_customer_support_tel?: string | undefined;
                    us_customer_support_email?: string | undefined;
                    us_customer_support_contact_url?: string | undefined;
                    seam_api_guide?: string | undefined;
                };
                is_device_supported: boolean;
                main_connection_type: "unknown" | "wifi" | "zwave" | "zigbee";
                hardware: {
                    has_physical_key?: boolean | undefined;
                };
                aesthetic_variants: {
                    display_name: string;
                    slug: string;
                    images: {
                        height: number;
                        width: number;
                        url: string;
                    }[];
                    primary_color_hex?: string | undefined;
                    manufacturer_sku?: string | undefined;
                    front_image?: {
                        height: number;
                        width: number;
                        url: string;
                    } | undefined;
                    back_image?: {
                        height: number;
                        width: number;
                        url: string;
                    } | undefined;
                }[];
                power_sources: ("battery" | "hardwired" | "mechanical_harvesting" | "wireless" | "ethernet")[];
                product_url?: string | undefined;
            } & {
                main_category: "accessory";
            });
        }, {
            device_model: ({
                description: string;
                display_name: string;
                device_model_id: string;
                manufacturer: {
                    display_name: string;
                    manufacturer_id: string;
                    integration: "beta" | "stable" | "planned" | "unsupported" | "inquire";
                    integration_support_level: "beta" | "stable" | "planned" | "unsupported" | "inquire";
                    is_connect_webview_supported: boolean;
                    requires_seam_support_to_add_account: boolean;
                    annotations: {
                        message: string;
                        annotation_code: "subscription_required";
                    }[];
                    description?: string | undefined;
                    logo?: {
                        height: number;
                        width: number;
                        url: string;
                    } | undefined;
                    website?: string | undefined;
                    legal_name?: string | undefined;
                    parent_organization?: string | undefined;
                    headquarters?: string[] | undefined;
                    countries_of_origin?: string[] | undefined;
                    founding_year?: string | undefined;
                    us_customer_support_tel?: string | undefined;
                    us_customer_support_email?: string | undefined;
                    us_customer_support_contact_url?: string | undefined;
                    seam_api_guide?: string | undefined;
                };
                is_device_supported: boolean;
                main_connection_type: "unknown" | "wifi" | "zwave" | "zigbee";
                hardware: {
                    has_physical_key?: boolean | undefined;
                };
                aesthetic_variants: {
                    display_name: string;
                    slug: string;
                    images: {
                        height: number;
                        width: number;
                        url: string;
                    }[];
                    primary_color_hex?: string | undefined;
                    manufacturer_sku?: string | undefined;
                    front_image?: {
                        height: number;
                        width: number;
                        url: string;
                    } | undefined;
                    back_image?: {
                        height: number;
                        width: number;
                        url: string;
                    } | undefined;
                }[];
                power_sources: ("battery" | "hardwired" | "mechanical_harvesting" | "wireless" | "ethernet")[];
                product_url?: string | undefined;
            } & {
                main_category: "smartlock";
                physical_properties: {
                    lock_type: "unknown" | "deadbolt" | "lever" | "mortise" | "lockbox" | "cylinder" | "padlock" | "locker";
                    has_physical_key: boolean;
                    has_camera: boolean;
                };
                software_features: {
                    can_remotely_unlock: boolean;
                    can_program_access_codes: boolean;
                    can_program_access_schedules: boolean;
                    can_program_access_codes_offline: boolean;
                };
                can_remotely_unlock?: true | undefined;
                can_remotely_lock?: true | undefined;
                can_program_offline_access_codes?: true | undefined;
                can_program_online_access_codes?: true | undefined;
            }) | ({
                description: string;
                display_name: string;
                device_model_id: string;
                manufacturer: {
                    display_name: string;
                    manufacturer_id: string;
                    integration: "beta" | "stable" | "planned" | "unsupported" | "inquire";
                    integration_support_level: "beta" | "stable" | "planned" | "unsupported" | "inquire";
                    is_connect_webview_supported: boolean;
                    requires_seam_support_to_add_account: boolean;
                    annotations: {
                        message: string;
                        annotation_code: "subscription_required";
                    }[];
                    description?: string | undefined;
                    logo?: {
                        height: number;
                        width: number;
                        url: string;
                    } | undefined;
                    website?: string | undefined;
                    legal_name?: string | undefined;
                    parent_organization?: string | undefined;
                    headquarters?: string[] | undefined;
                    countries_of_origin?: string[] | undefined;
                    founding_year?: string | undefined;
                    us_customer_support_tel?: string | undefined;
                    us_customer_support_email?: string | undefined;
                    us_customer_support_contact_url?: string | undefined;
                    seam_api_guide?: string | undefined;
                };
                is_device_supported: boolean;
                main_connection_type: "unknown" | "wifi" | "zwave" | "zigbee";
                hardware: {
                    has_physical_key?: boolean | undefined;
                };
                aesthetic_variants: {
                    display_name: string;
                    slug: string;
                    images: {
                        height: number;
                        width: number;
                        url: string;
                    }[];
                    primary_color_hex?: string | undefined;
                    manufacturer_sku?: string | undefined;
                    front_image?: {
                        height: number;
                        width: number;
                        url: string;
                    } | undefined;
                    back_image?: {
                        height: number;
                        width: number;
                        url: string;
                    } | undefined;
                }[];
                power_sources: ("battery" | "hardwired" | "mechanical_harvesting" | "wireless" | "ethernet")[];
                product_url?: string | undefined;
            } & {
                main_category: "sensor";
                physical_properties: {
                    has_noise_sensor: boolean;
                    has_humidity_sensor: boolean;
                    has_temperature_sensor: boolean;
                    has_occupancy_detection: boolean;
                };
            }) | ({
                description: string;
                display_name: string;
                device_model_id: string;
                manufacturer: {
                    display_name: string;
                    manufacturer_id: string;
                    integration: "beta" | "stable" | "planned" | "unsupported" | "inquire";
                    integration_support_level: "beta" | "stable" | "planned" | "unsupported" | "inquire";
                    is_connect_webview_supported: boolean;
                    requires_seam_support_to_add_account: boolean;
                    annotations: {
                        message: string;
                        annotation_code: "subscription_required";
                    }[];
                    description?: string | undefined;
                    logo?: {
                        height: number;
                        width: number;
                        url: string;
                    } | undefined;
                    website?: string | undefined;
                    legal_name?: string | undefined;
                    parent_organization?: string | undefined;
                    headquarters?: string[] | undefined;
                    countries_of_origin?: string[] | undefined;
                    founding_year?: string | undefined;
                    us_customer_support_tel?: string | undefined;
                    us_customer_support_email?: string | undefined;
                    us_customer_support_contact_url?: string | undefined;
                    seam_api_guide?: string | undefined;
                };
                is_device_supported: boolean;
                main_connection_type: "unknown" | "wifi" | "zwave" | "zigbee";
                hardware: {
                    has_physical_key?: boolean | undefined;
                };
                aesthetic_variants: {
                    display_name: string;
                    slug: string;
                    images: {
                        height: number;
                        width: number;
                        url: string;
                    }[];
                    primary_color_hex?: string | undefined;
                    manufacturer_sku?: string | undefined;
                    front_image?: {
                        height: number;
                        width: number;
                        url: string;
                    } | undefined;
                    back_image?: {
                        height: number;
                        width: number;
                        url: string;
                    } | undefined;
                }[];
                power_sources: ("battery" | "hardwired" | "mechanical_harvesting" | "wireless" | "ethernet")[];
                product_url?: string | undefined;
            } & {
                main_category: "thermostat";
                physical_properties: {
                    has_humidity_sensor: boolean;
                    has_temperature_sensor: boolean;
                    has_occupancy_detection: boolean;
                    available_modes: ("heat" | "cool" | "fan" | "eco")[];
                    is_heat_pump_compatible: boolean;
                    supports_demand_response: boolean;
                    supports_emergency_heating_mode: boolean;
                };
                software_features: {
                    can_program_climate_schedules: boolean;
                };
            }) | ({
                description: string;
                display_name: string;
                device_model_id: string;
                manufacturer: {
                    display_name: string;
                    manufacturer_id: string;
                    integration: "beta" | "stable" | "planned" | "unsupported" | "inquire";
                    integration_support_level: "beta" | "stable" | "planned" | "unsupported" | "inquire";
                    is_connect_webview_supported: boolean;
                    requires_seam_support_to_add_account: boolean;
                    annotations: {
                        message: string;
                        annotation_code: "subscription_required";
                    }[];
                    description?: string | undefined;
                    logo?: {
                        height: number;
                        width: number;
                        url: string;
                    } | undefined;
                    website?: string | undefined;
                    legal_name?: string | undefined;
                    parent_organization?: string | undefined;
                    headquarters?: string[] | undefined;
                    countries_of_origin?: string[] | undefined;
                    founding_year?: string | undefined;
                    us_customer_support_tel?: string | undefined;
                    us_customer_support_email?: string | undefined;
                    us_customer_support_contact_url?: string | undefined;
                    seam_api_guide?: string | undefined;
                };
                is_device_supported: boolean;
                main_connection_type: "unknown" | "wifi" | "zwave" | "zigbee";
                hardware: {
                    has_physical_key?: boolean | undefined;
                };
                aesthetic_variants: {
                    display_name: string;
                    slug: string;
                    images: {
                        height: number;
                        width: number;
                        url: string;
                    }[];
                    primary_color_hex?: string | undefined;
                    manufacturer_sku?: string | undefined;
                    front_image?: {
                        height: number;
                        width: number;
                        url: string;
                    } | undefined;
                    back_image?: {
                        height: number;
                        width: number;
                        url: string;
                    } | undefined;
                }[];
                power_sources: ("battery" | "hardwired" | "mechanical_harvesting" | "wireless" | "ethernet")[];
                product_url?: string | undefined;
            } & {
                main_category: "relay";
            }) | ({
                description: string;
                display_name: string;
                device_model_id: string;
                manufacturer: {
                    display_name: string;
                    manufacturer_id: string;
                    integration: "beta" | "stable" | "planned" | "unsupported" | "inquire";
                    integration_support_level: "beta" | "stable" | "planned" | "unsupported" | "inquire";
                    is_connect_webview_supported: boolean;
                    requires_seam_support_to_add_account: boolean;
                    annotations: {
                        message: string;
                        annotation_code: "subscription_required";
                    }[];
                    description?: string | undefined;
                    logo?: {
                        height: number;
                        width: number;
                        url: string;
                    } | undefined;
                    website?: string | undefined;
                    legal_name?: string | undefined;
                    parent_organization?: string | undefined;
                    headquarters?: string[] | undefined;
                    countries_of_origin?: string[] | undefined;
                    founding_year?: string | undefined;
                    us_customer_support_tel?: string | undefined;
                    us_customer_support_email?: string | undefined;
                    us_customer_support_contact_url?: string | undefined;
                    seam_api_guide?: string | undefined;
                };
                is_device_supported: boolean;
                main_connection_type: "unknown" | "wifi" | "zwave" | "zigbee";
                hardware: {
                    has_physical_key?: boolean | undefined;
                };
                aesthetic_variants: {
                    display_name: string;
                    slug: string;
                    images: {
                        height: number;
                        width: number;
                        url: string;
                    }[];
                    primary_color_hex?: string | undefined;
                    manufacturer_sku?: string | undefined;
                    front_image?: {
                        height: number;
                        width: number;
                        url: string;
                    } | undefined;
                    back_image?: {
                        height: number;
                        width: number;
                        url: string;
                    } | undefined;
                }[];
                power_sources: ("battery" | "hardwired" | "mechanical_harvesting" | "wireless" | "ethernet")[];
                product_url?: string | undefined;
            } & {
                main_category: "intercom";
                physical_properties: {
                    has_camera: boolean;
                    has_rfid_reader?: boolean | undefined;
                    has_nfc_reader?: boolean | undefined;
                    has_wiegand_interface?: boolean | undefined;
                };
                software_features: {
                    can_remotely_unlock: boolean;
                    can_program_access_codes: boolean;
                    can_unlock_with_face_recognition?: boolean | undefined;
                    supports_onvif?: boolean | undefined;
                };
            }) | ({
                description: string;
                display_name: string;
                device_model_id: string;
                manufacturer: {
                    display_name: string;
                    manufacturer_id: string;
                    integration: "beta" | "stable" | "planned" | "unsupported" | "inquire";
                    integration_support_level: "beta" | "stable" | "planned" | "unsupported" | "inquire";
                    is_connect_webview_supported: boolean;
                    requires_seam_support_to_add_account: boolean;
                    annotations: {
                        message: string;
                        annotation_code: "subscription_required";
                    }[];
                    description?: string | undefined;
                    logo?: {
                        height: number;
                        width: number;
                        url: string;
                    } | undefined;
                    website?: string | undefined;
                    legal_name?: string | undefined;
                    parent_organization?: string | undefined;
                    headquarters?: string[] | undefined;
                    countries_of_origin?: string[] | undefined;
                    founding_year?: string | undefined;
                    us_customer_support_tel?: string | undefined;
                    us_customer_support_email?: string | undefined;
                    us_customer_support_contact_url?: string | undefined;
                    seam_api_guide?: string | undefined;
                };
                is_device_supported: boolean;
                main_connection_type: "unknown" | "wifi" | "zwave" | "zigbee";
                hardware: {
                    has_physical_key?: boolean | undefined;
                };
                aesthetic_variants: {
                    display_name: string;
                    slug: string;
                    images: {
                        height: number;
                        width: number;
                        url: string;
                    }[];
                    primary_color_hex?: string | undefined;
                    manufacturer_sku?: string | undefined;
                    front_image?: {
                        height: number;
                        width: number;
                        url: string;
                    } | undefined;
                    back_image?: {
                        height: number;
                        width: number;
                        url: string;
                    } | undefined;
                }[];
                power_sources: ("battery" | "hardwired" | "mechanical_harvesting" | "wireless" | "ethernet")[];
                product_url?: string | undefined;
            } & {
                main_category: "accessory";
            });
        }>;
    };
    readonly '/api/v1/device_models/list': {
        readonly auth: "publishable_key";
        readonly methods: readonly ["GET", "OPTIONS"];
        readonly queryParams: z.ZodObject<{
            main_category: z.ZodOptional<z.ZodEnum<["smartlock", "sensor", "thermostat", "relay", "intercom", "accessory"]>>;
            manufacturer_id: z.ZodOptional<z.ZodString>;
            manufacturer_ids: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
            /** @deprecated */
            integration_status: z.ZodOptional<z.ZodEnum<["stable", "beta", "planned", "unsupported", "inquire"]>>;
            integration_support_levels: z.ZodOptional<z.ZodArray<z.ZodEnum<["stable", "beta", "planned", "unsupported", "inquire"]>, "many">>;
            text_search: z.ZodOptional<z.ZodString>;
            include_if: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
            exclude_if: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
        }, "strip", z.ZodTypeAny, {
            main_category?: "relay" | "thermostat" | "smartlock" | "sensor" | "intercom" | "accessory" | undefined;
            manufacturer_id?: string | undefined;
            manufacturer_ids?: string[] | undefined;
            integration_status?: "beta" | "stable" | "planned" | "unsupported" | "inquire" | undefined;
            integration_support_levels?: ("beta" | "stable" | "planned" | "unsupported" | "inquire")[] | undefined;
            text_search?: string | undefined;
            include_if?: string[] | undefined;
            exclude_if?: string[] | undefined;
        }, {
            main_category?: "relay" | "thermostat" | "smartlock" | "sensor" | "intercom" | "accessory" | undefined;
            manufacturer_id?: string | undefined;
            manufacturer_ids?: string[] | undefined;
            integration_status?: "beta" | "stable" | "planned" | "unsupported" | "inquire" | undefined;
            integration_support_levels?: ("beta" | "stable" | "planned" | "unsupported" | "inquire")[] | undefined;
            text_search?: string | undefined;
            include_if?: string[] | undefined;
            exclude_if?: string[] | undefined;
        }>;
        readonly jsonResponse: z.ZodObject<{
            device_models: z.ZodArray<z.ZodIntersection<z.ZodObject<{
                device_model_id: z.ZodString;
                manufacturer: z.ZodObject<Omit<{
                    manufacturer_id: z.ZodString;
                    display_name: z.ZodString;
                    logo: z.ZodOptional<z.ZodObject<{
                        url: z.ZodString;
                        width: z.ZodNumber;
                        height: z.ZodNumber;
                    }, "strip", z.ZodTypeAny, {
                        height: number;
                        width: number;
                        url: string;
                    }, {
                        height: number;
                        width: number;
                        url: string;
                    }>>;
                    integration: z.ZodEnum<["stable", "beta", "planned", "unsupported", "inquire"]>;
                    integration_support_level: z.ZodEnum<["stable", "beta", "planned", "unsupported", "inquire"]>;
                    is_connect_webview_supported: z.ZodBoolean;
                    requires_seam_support_to_add_account: z.ZodBoolean;
                    device_model_count: z.ZodNumber;
                    annotations: z.ZodArray<z.ZodObject<{
                        annotation_code: z.ZodEnum<["subscription_required"]>;
                        message: z.ZodString;
                    }, "strip", z.ZodTypeAny, {
                        message: string;
                        annotation_code: "subscription_required";
                    }, {
                        message: string;
                        annotation_code: "subscription_required";
                    }>, "many">;
                    website: z.ZodOptional<z.ZodString>;
                    legal_name: z.ZodOptional<z.ZodString>;
                    parent_organization: z.ZodOptional<z.ZodString>;
                    headquarters: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                    countries_of_origin: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                    founding_year: z.ZodOptional<z.ZodString>;
                    us_customer_support_tel: z.ZodOptional<z.ZodString>;
                    us_customer_support_email: z.ZodOptional<z.ZodString>;
                    /** @deprecated */
                    us_customer_support_contact_url: z.ZodOptional<z.ZodString>;
                    seam_api_guide: z.ZodOptional<z.ZodString>;
                    description: z.ZodOptional<z.ZodString>;
                }, "device_model_count">, "strip", z.ZodTypeAny, {
                    display_name: string;
                    manufacturer_id: string;
                    integration: "beta" | "stable" | "planned" | "unsupported" | "inquire";
                    integration_support_level: "beta" | "stable" | "planned" | "unsupported" | "inquire";
                    is_connect_webview_supported: boolean;
                    requires_seam_support_to_add_account: boolean;
                    annotations: {
                        message: string;
                        annotation_code: "subscription_required";
                    }[];
                    description?: string | undefined;
                    logo?: {
                        height: number;
                        width: number;
                        url: string;
                    } | undefined;
                    website?: string | undefined;
                    legal_name?: string | undefined;
                    parent_organization?: string | undefined;
                    headquarters?: string[] | undefined;
                    countries_of_origin?: string[] | undefined;
                    founding_year?: string | undefined;
                    us_customer_support_tel?: string | undefined;
                    us_customer_support_email?: string | undefined;
                    us_customer_support_contact_url?: string | undefined;
                    seam_api_guide?: string | undefined;
                }, {
                    display_name: string;
                    manufacturer_id: string;
                    integration: "beta" | "stable" | "planned" | "unsupported" | "inquire";
                    integration_support_level: "beta" | "stable" | "planned" | "unsupported" | "inquire";
                    is_connect_webview_supported: boolean;
                    requires_seam_support_to_add_account: boolean;
                    annotations: {
                        message: string;
                        annotation_code: "subscription_required";
                    }[];
                    description?: string | undefined;
                    logo?: {
                        height: number;
                        width: number;
                        url: string;
                    } | undefined;
                    website?: string | undefined;
                    legal_name?: string | undefined;
                    parent_organization?: string | undefined;
                    headquarters?: string[] | undefined;
                    countries_of_origin?: string[] | undefined;
                    founding_year?: string | undefined;
                    us_customer_support_tel?: string | undefined;
                    us_customer_support_email?: string | undefined;
                    us_customer_support_contact_url?: string | undefined;
                    seam_api_guide?: string | undefined;
                }>;
                is_device_supported: z.ZodBoolean;
                display_name: z.ZodString;
                description: z.ZodString;
                product_url: z.ZodOptional<z.ZodString>;
                main_connection_type: z.ZodEnum<["wifi", "zwave", "zigbee", "unknown"]>;
                hardware: z.ZodObject<{
                    has_physical_key: z.ZodOptional<z.ZodBoolean>;
                }, "strip", z.ZodTypeAny, {
                    has_physical_key?: boolean | undefined;
                }, {
                    has_physical_key?: boolean | undefined;
                }>;
                aesthetic_variants: z.ZodArray<z.ZodObject<{
                    slug: z.ZodString;
                    display_name: z.ZodString;
                    primary_color_hex: z.ZodOptional<z.ZodString>;
                    manufacturer_sku: z.ZodOptional<z.ZodString>;
                    front_image: z.ZodOptional<z.ZodObject<{
                        url: z.ZodString;
                        width: z.ZodNumber;
                        height: z.ZodNumber;
                    }, "strip", z.ZodTypeAny, {
                        height: number;
                        width: number;
                        url: string;
                    }, {
                        height: number;
                        width: number;
                        url: string;
                    }>>;
                    back_image: z.ZodOptional<z.ZodObject<{
                        url: z.ZodString;
                        width: z.ZodNumber;
                        height: z.ZodNumber;
                    }, "strip", z.ZodTypeAny, {
                        height: number;
                        width: number;
                        url: string;
                    }, {
                        height: number;
                        width: number;
                        url: string;
                    }>>;
                    images: z.ZodArray<z.ZodObject<{
                        url: z.ZodString;
                        width: z.ZodNumber;
                        height: z.ZodNumber;
                    }, "strip", z.ZodTypeAny, {
                        height: number;
                        width: number;
                        url: string;
                    }, {
                        height: number;
                        width: number;
                        url: string;
                    }>, "many">;
                }, "strip", z.ZodTypeAny, {
                    display_name: string;
                    slug: string;
                    images: {
                        height: number;
                        width: number;
                        url: string;
                    }[];
                    primary_color_hex?: string | undefined;
                    manufacturer_sku?: string | undefined;
                    front_image?: {
                        height: number;
                        width: number;
                        url: string;
                    } | undefined;
                    back_image?: {
                        height: number;
                        width: number;
                        url: string;
                    } | undefined;
                }, {
                    display_name: string;
                    slug: string;
                    images: {
                        height: number;
                        width: number;
                        url: string;
                    }[];
                    primary_color_hex?: string | undefined;
                    manufacturer_sku?: string | undefined;
                    front_image?: {
                        height: number;
                        width: number;
                        url: string;
                    } | undefined;
                    back_image?: {
                        height: number;
                        width: number;
                        url: string;
                    } | undefined;
                }>, "many">;
                power_sources: z.ZodArray<z.ZodEnum<["battery", "hardwired", "mechanical_harvesting", "wireless", "ethernet"]>, "many">;
            }, "strip", z.ZodTypeAny, {
                description: string;
                display_name: string;
                device_model_id: string;
                manufacturer: {
                    display_name: string;
                    manufacturer_id: string;
                    integration: "beta" | "stable" | "planned" | "unsupported" | "inquire";
                    integration_support_level: "beta" | "stable" | "planned" | "unsupported" | "inquire";
                    is_connect_webview_supported: boolean;
                    requires_seam_support_to_add_account: boolean;
                    annotations: {
                        message: string;
                        annotation_code: "subscription_required";
                    }[];
                    description?: string | undefined;
                    logo?: {
                        height: number;
                        width: number;
                        url: string;
                    } | undefined;
                    website?: string | undefined;
                    legal_name?: string | undefined;
                    parent_organization?: string | undefined;
                    headquarters?: string[] | undefined;
                    countries_of_origin?: string[] | undefined;
                    founding_year?: string | undefined;
                    us_customer_support_tel?: string | undefined;
                    us_customer_support_email?: string | undefined;
                    us_customer_support_contact_url?: string | undefined;
                    seam_api_guide?: string | undefined;
                };
                is_device_supported: boolean;
                main_connection_type: "unknown" | "wifi" | "zwave" | "zigbee";
                hardware: {
                    has_physical_key?: boolean | undefined;
                };
                aesthetic_variants: {
                    display_name: string;
                    slug: string;
                    images: {
                        height: number;
                        width: number;
                        url: string;
                    }[];
                    primary_color_hex?: string | undefined;
                    manufacturer_sku?: string | undefined;
                    front_image?: {
                        height: number;
                        width: number;
                        url: string;
                    } | undefined;
                    back_image?: {
                        height: number;
                        width: number;
                        url: string;
                    } | undefined;
                }[];
                power_sources: ("battery" | "hardwired" | "mechanical_harvesting" | "wireless" | "ethernet")[];
                product_url?: string | undefined;
            }, {
                description: string;
                display_name: string;
                device_model_id: string;
                manufacturer: {
                    display_name: string;
                    manufacturer_id: string;
                    integration: "beta" | "stable" | "planned" | "unsupported" | "inquire";
                    integration_support_level: "beta" | "stable" | "planned" | "unsupported" | "inquire";
                    is_connect_webview_supported: boolean;
                    requires_seam_support_to_add_account: boolean;
                    annotations: {
                        message: string;
                        annotation_code: "subscription_required";
                    }[];
                    description?: string | undefined;
                    logo?: {
                        height: number;
                        width: number;
                        url: string;
                    } | undefined;
                    website?: string | undefined;
                    legal_name?: string | undefined;
                    parent_organization?: string | undefined;
                    headquarters?: string[] | undefined;
                    countries_of_origin?: string[] | undefined;
                    founding_year?: string | undefined;
                    us_customer_support_tel?: string | undefined;
                    us_customer_support_email?: string | undefined;
                    us_customer_support_contact_url?: string | undefined;
                    seam_api_guide?: string | undefined;
                };
                is_device_supported: boolean;
                main_connection_type: "unknown" | "wifi" | "zwave" | "zigbee";
                hardware: {
                    has_physical_key?: boolean | undefined;
                };
                aesthetic_variants: {
                    display_name: string;
                    slug: string;
                    images: {
                        height: number;
                        width: number;
                        url: string;
                    }[];
                    primary_color_hex?: string | undefined;
                    manufacturer_sku?: string | undefined;
                    front_image?: {
                        height: number;
                        width: number;
                        url: string;
                    } | undefined;
                    back_image?: {
                        height: number;
                        width: number;
                        url: string;
                    } | undefined;
                }[];
                power_sources: ("battery" | "hardwired" | "mechanical_harvesting" | "wireless" | "ethernet")[];
                product_url?: string | undefined;
            }>, z.ZodDiscriminatedUnion<"main_category", [z.ZodObject<{
                main_category: z.ZodLiteral<"smartlock">;
                physical_properties: z.ZodObject<{
                    lock_type: z.ZodEnum<["deadbolt", "lever", "mortise", "lockbox", "cylinder", "padlock", "locker", "unknown"]>;
                    has_physical_key: z.ZodBoolean;
                    has_camera: z.ZodBoolean;
                }, "strip", z.ZodTypeAny, {
                    lock_type: "unknown" | "deadbolt" | "lever" | "mortise" | "lockbox" | "cylinder" | "padlock" | "locker";
                    has_physical_key: boolean;
                    has_camera: boolean;
                }, {
                    lock_type: "unknown" | "deadbolt" | "lever" | "mortise" | "lockbox" | "cylinder" | "padlock" | "locker";
                    has_physical_key: boolean;
                    has_camera: boolean;
                }>;
                software_features: z.ZodObject<{
                    can_remotely_unlock: z.ZodBoolean;
                    can_program_access_codes: z.ZodBoolean;
                    can_program_access_schedules: z.ZodBoolean;
                    can_program_access_codes_offline: z.ZodBoolean;
                }, "strip", z.ZodTypeAny, {
                    can_remotely_unlock: boolean;
                    can_program_access_codes: boolean;
                    can_program_access_schedules: boolean;
                    can_program_access_codes_offline: boolean;
                }, {
                    can_remotely_unlock: boolean;
                    can_program_access_codes: boolean;
                    can_program_access_schedules: boolean;
                    can_program_access_codes_offline: boolean;
                }>;
                can_remotely_unlock: z.ZodOptional<z.ZodLiteral<true>>;
                can_remotely_lock: z.ZodOptional<z.ZodLiteral<true>>;
                can_program_offline_access_codes: z.ZodOptional<z.ZodLiteral<true>>;
                can_program_online_access_codes: z.ZodOptional<z.ZodLiteral<true>>;
            }, "strip", z.ZodTypeAny, {
                main_category: "smartlock";
                physical_properties: {
                    lock_type: "unknown" | "deadbolt" | "lever" | "mortise" | "lockbox" | "cylinder" | "padlock" | "locker";
                    has_physical_key: boolean;
                    has_camera: boolean;
                };
                software_features: {
                    can_remotely_unlock: boolean;
                    can_program_access_codes: boolean;
                    can_program_access_schedules: boolean;
                    can_program_access_codes_offline: boolean;
                };
                can_remotely_unlock?: true | undefined;
                can_remotely_lock?: true | undefined;
                can_program_offline_access_codes?: true | undefined;
                can_program_online_access_codes?: true | undefined;
            }, {
                main_category: "smartlock";
                physical_properties: {
                    lock_type: "unknown" | "deadbolt" | "lever" | "mortise" | "lockbox" | "cylinder" | "padlock" | "locker";
                    has_physical_key: boolean;
                    has_camera: boolean;
                };
                software_features: {
                    can_remotely_unlock: boolean;
                    can_program_access_codes: boolean;
                    can_program_access_schedules: boolean;
                    can_program_access_codes_offline: boolean;
                };
                can_remotely_unlock?: true | undefined;
                can_remotely_lock?: true | undefined;
                can_program_offline_access_codes?: true | undefined;
                can_program_online_access_codes?: true | undefined;
            }>, z.ZodObject<{
                main_category: z.ZodLiteral<"sensor">;
                physical_properties: z.ZodObject<{
                    has_noise_sensor: z.ZodBoolean;
                    has_humidity_sensor: z.ZodBoolean;
                    has_temperature_sensor: z.ZodBoolean;
                    has_occupancy_detection: z.ZodBoolean;
                }, "strip", z.ZodTypeAny, {
                    has_noise_sensor: boolean;
                    has_humidity_sensor: boolean;
                    has_temperature_sensor: boolean;
                    has_occupancy_detection: boolean;
                }, {
                    has_noise_sensor: boolean;
                    has_humidity_sensor: boolean;
                    has_temperature_sensor: boolean;
                    has_occupancy_detection: boolean;
                }>;
            }, "strip", z.ZodTypeAny, {
                main_category: "sensor";
                physical_properties: {
                    has_noise_sensor: boolean;
                    has_humidity_sensor: boolean;
                    has_temperature_sensor: boolean;
                    has_occupancy_detection: boolean;
                };
            }, {
                main_category: "sensor";
                physical_properties: {
                    has_noise_sensor: boolean;
                    has_humidity_sensor: boolean;
                    has_temperature_sensor: boolean;
                    has_occupancy_detection: boolean;
                };
            }>, z.ZodObject<{
                main_category: z.ZodLiteral<"thermostat">;
                physical_properties: z.ZodObject<{
                    available_modes: z.ZodArray<z.ZodEnum<["heat", "cool", "fan", "eco"]>, "many">;
                    is_heat_pump_compatible: z.ZodBoolean;
                    has_occupancy_detection: z.ZodBoolean;
                    supports_demand_response: z.ZodBoolean;
                    has_humidity_sensor: z.ZodBoolean;
                    has_temperature_sensor: z.ZodBoolean;
                    supports_emergency_heating_mode: z.ZodBoolean;
                }, "strip", z.ZodTypeAny, {
                    has_humidity_sensor: boolean;
                    has_temperature_sensor: boolean;
                    has_occupancy_detection: boolean;
                    available_modes: ("heat" | "cool" | "fan" | "eco")[];
                    is_heat_pump_compatible: boolean;
                    supports_demand_response: boolean;
                    supports_emergency_heating_mode: boolean;
                }, {
                    has_humidity_sensor: boolean;
                    has_temperature_sensor: boolean;
                    has_occupancy_detection: boolean;
                    available_modes: ("heat" | "cool" | "fan" | "eco")[];
                    is_heat_pump_compatible: boolean;
                    supports_demand_response: boolean;
                    supports_emergency_heating_mode: boolean;
                }>;
                software_features: z.ZodObject<{
                    can_program_climate_schedules: z.ZodBoolean;
                }, "strip", z.ZodTypeAny, {
                    can_program_climate_schedules: boolean;
                }, {
                    can_program_climate_schedules: boolean;
                }>;
            }, "strip", z.ZodTypeAny, {
                main_category: "thermostat";
                physical_properties: {
                    has_humidity_sensor: boolean;
                    has_temperature_sensor: boolean;
                    has_occupancy_detection: boolean;
                    available_modes: ("heat" | "cool" | "fan" | "eco")[];
                    is_heat_pump_compatible: boolean;
                    supports_demand_response: boolean;
                    supports_emergency_heating_mode: boolean;
                };
                software_features: {
                    can_program_climate_schedules: boolean;
                };
            }, {
                main_category: "thermostat";
                physical_properties: {
                    has_humidity_sensor: boolean;
                    has_temperature_sensor: boolean;
                    has_occupancy_detection: boolean;
                    available_modes: ("heat" | "cool" | "fan" | "eco")[];
                    is_heat_pump_compatible: boolean;
                    supports_demand_response: boolean;
                    supports_emergency_heating_mode: boolean;
                };
                software_features: {
                    can_program_climate_schedules: boolean;
                };
            }>, z.ZodObject<{
                main_category: z.ZodLiteral<"relay">;
            }, "strip", z.ZodTypeAny, {
                main_category: "relay";
            }, {
                main_category: "relay";
            }>, z.ZodObject<{
                main_category: z.ZodLiteral<"intercom">;
                physical_properties: z.ZodObject<{
                    has_camera: z.ZodBoolean;
                    has_rfid_reader: z.ZodDefault<z.ZodBoolean>;
                    has_nfc_reader: z.ZodDefault<z.ZodBoolean>;
                    has_wiegand_interface: z.ZodDefault<z.ZodBoolean>;
                }, "strip", z.ZodTypeAny, {
                    has_camera: boolean;
                    has_rfid_reader: boolean;
                    has_nfc_reader: boolean;
                    has_wiegand_interface: boolean;
                }, {
                    has_camera: boolean;
                    has_rfid_reader?: boolean | undefined;
                    has_nfc_reader?: boolean | undefined;
                    has_wiegand_interface?: boolean | undefined;
                }>;
                software_features: z.ZodObject<{
                    can_remotely_unlock: z.ZodBoolean;
                    can_program_access_codes: z.ZodBoolean;
                    can_unlock_with_face_recognition: z.ZodDefault<z.ZodBoolean>;
                    supports_onvif: z.ZodDefault<z.ZodBoolean>;
                }, "strip", z.ZodTypeAny, {
                    can_remotely_unlock: boolean;
                    can_program_access_codes: boolean;
                    can_unlock_with_face_recognition: boolean;
                    supports_onvif: boolean;
                }, {
                    can_remotely_unlock: boolean;
                    can_program_access_codes: boolean;
                    can_unlock_with_face_recognition?: boolean | undefined;
                    supports_onvif?: boolean | undefined;
                }>;
            }, "strip", z.ZodTypeAny, {
                main_category: "intercom";
                physical_properties: {
                    has_camera: boolean;
                    has_rfid_reader: boolean;
                    has_nfc_reader: boolean;
                    has_wiegand_interface: boolean;
                };
                software_features: {
                    can_remotely_unlock: boolean;
                    can_program_access_codes: boolean;
                    can_unlock_with_face_recognition: boolean;
                    supports_onvif: boolean;
                };
            }, {
                main_category: "intercom";
                physical_properties: {
                    has_camera: boolean;
                    has_rfid_reader?: boolean | undefined;
                    has_nfc_reader?: boolean | undefined;
                    has_wiegand_interface?: boolean | undefined;
                };
                software_features: {
                    can_remotely_unlock: boolean;
                    can_program_access_codes: boolean;
                    can_unlock_with_face_recognition?: boolean | undefined;
                    supports_onvif?: boolean | undefined;
                };
            }>, z.ZodObject<{
                main_category: z.ZodLiteral<"accessory">;
            }, "strip", z.ZodTypeAny, {
                main_category: "accessory";
            }, {
                main_category: "accessory";
            }>]>>, "many">;
        }, "strip", z.ZodTypeAny, {
            device_models: ({
                description: string;
                display_name: string;
                device_model_id: string;
                manufacturer: {
                    display_name: string;
                    manufacturer_id: string;
                    integration: "beta" | "stable" | "planned" | "unsupported" | "inquire";
                    integration_support_level: "beta" | "stable" | "planned" | "unsupported" | "inquire";
                    is_connect_webview_supported: boolean;
                    requires_seam_support_to_add_account: boolean;
                    annotations: {
                        message: string;
                        annotation_code: "subscription_required";
                    }[];
                    description?: string | undefined;
                    logo?: {
                        height: number;
                        width: number;
                        url: string;
                    } | undefined;
                    website?: string | undefined;
                    legal_name?: string | undefined;
                    parent_organization?: string | undefined;
                    headquarters?: string[] | undefined;
                    countries_of_origin?: string[] | undefined;
                    founding_year?: string | undefined;
                    us_customer_support_tel?: string | undefined;
                    us_customer_support_email?: string | undefined;
                    us_customer_support_contact_url?: string | undefined;
                    seam_api_guide?: string | undefined;
                };
                is_device_supported: boolean;
                main_connection_type: "unknown" | "wifi" | "zwave" | "zigbee";
                hardware: {
                    has_physical_key?: boolean | undefined;
                };
                aesthetic_variants: {
                    display_name: string;
                    slug: string;
                    images: {
                        height: number;
                        width: number;
                        url: string;
                    }[];
                    primary_color_hex?: string | undefined;
                    manufacturer_sku?: string | undefined;
                    front_image?: {
                        height: number;
                        width: number;
                        url: string;
                    } | undefined;
                    back_image?: {
                        height: number;
                        width: number;
                        url: string;
                    } | undefined;
                }[];
                power_sources: ("battery" | "hardwired" | "mechanical_harvesting" | "wireless" | "ethernet")[];
                product_url?: string | undefined;
            } & ({
                main_category: "smartlock";
                physical_properties: {
                    lock_type: "unknown" | "deadbolt" | "lever" | "mortise" | "lockbox" | "cylinder" | "padlock" | "locker";
                    has_physical_key: boolean;
                    has_camera: boolean;
                };
                software_features: {
                    can_remotely_unlock: boolean;
                    can_program_access_codes: boolean;
                    can_program_access_schedules: boolean;
                    can_program_access_codes_offline: boolean;
                };
                can_remotely_unlock?: true | undefined;
                can_remotely_lock?: true | undefined;
                can_program_offline_access_codes?: true | undefined;
                can_program_online_access_codes?: true | undefined;
            } | {
                main_category: "sensor";
                physical_properties: {
                    has_noise_sensor: boolean;
                    has_humidity_sensor: boolean;
                    has_temperature_sensor: boolean;
                    has_occupancy_detection: boolean;
                };
            } | {
                main_category: "thermostat";
                physical_properties: {
                    has_humidity_sensor: boolean;
                    has_temperature_sensor: boolean;
                    has_occupancy_detection: boolean;
                    available_modes: ("heat" | "cool" | "fan" | "eco")[];
                    is_heat_pump_compatible: boolean;
                    supports_demand_response: boolean;
                    supports_emergency_heating_mode: boolean;
                };
                software_features: {
                    can_program_climate_schedules: boolean;
                };
            } | {
                main_category: "relay";
            } | {
                main_category: "intercom";
                physical_properties: {
                    has_camera: boolean;
                    has_rfid_reader: boolean;
                    has_nfc_reader: boolean;
                    has_wiegand_interface: boolean;
                };
                software_features: {
                    can_remotely_unlock: boolean;
                    can_program_access_codes: boolean;
                    can_unlock_with_face_recognition: boolean;
                    supports_onvif: boolean;
                };
            } | {
                main_category: "accessory";
            }))[];
        }, {
            device_models: ({
                description: string;
                display_name: string;
                device_model_id: string;
                manufacturer: {
                    display_name: string;
                    manufacturer_id: string;
                    integration: "beta" | "stable" | "planned" | "unsupported" | "inquire";
                    integration_support_level: "beta" | "stable" | "planned" | "unsupported" | "inquire";
                    is_connect_webview_supported: boolean;
                    requires_seam_support_to_add_account: boolean;
                    annotations: {
                        message: string;
                        annotation_code: "subscription_required";
                    }[];
                    description?: string | undefined;
                    logo?: {
                        height: number;
                        width: number;
                        url: string;
                    } | undefined;
                    website?: string | undefined;
                    legal_name?: string | undefined;
                    parent_organization?: string | undefined;
                    headquarters?: string[] | undefined;
                    countries_of_origin?: string[] | undefined;
                    founding_year?: string | undefined;
                    us_customer_support_tel?: string | undefined;
                    us_customer_support_email?: string | undefined;
                    us_customer_support_contact_url?: string | undefined;
                    seam_api_guide?: string | undefined;
                };
                is_device_supported: boolean;
                main_connection_type: "unknown" | "wifi" | "zwave" | "zigbee";
                hardware: {
                    has_physical_key?: boolean | undefined;
                };
                aesthetic_variants: {
                    display_name: string;
                    slug: string;
                    images: {
                        height: number;
                        width: number;
                        url: string;
                    }[];
                    primary_color_hex?: string | undefined;
                    manufacturer_sku?: string | undefined;
                    front_image?: {
                        height: number;
                        width: number;
                        url: string;
                    } | undefined;
                    back_image?: {
                        height: number;
                        width: number;
                        url: string;
                    } | undefined;
                }[];
                power_sources: ("battery" | "hardwired" | "mechanical_harvesting" | "wireless" | "ethernet")[];
                product_url?: string | undefined;
            } & ({
                main_category: "smartlock";
                physical_properties: {
                    lock_type: "unknown" | "deadbolt" | "lever" | "mortise" | "lockbox" | "cylinder" | "padlock" | "locker";
                    has_physical_key: boolean;
                    has_camera: boolean;
                };
                software_features: {
                    can_remotely_unlock: boolean;
                    can_program_access_codes: boolean;
                    can_program_access_schedules: boolean;
                    can_program_access_codes_offline: boolean;
                };
                can_remotely_unlock?: true | undefined;
                can_remotely_lock?: true | undefined;
                can_program_offline_access_codes?: true | undefined;
                can_program_online_access_codes?: true | undefined;
            } | {
                main_category: "sensor";
                physical_properties: {
                    has_noise_sensor: boolean;
                    has_humidity_sensor: boolean;
                    has_temperature_sensor: boolean;
                    has_occupancy_detection: boolean;
                };
            } | {
                main_category: "thermostat";
                physical_properties: {
                    has_humidity_sensor: boolean;
                    has_temperature_sensor: boolean;
                    has_occupancy_detection: boolean;
                    available_modes: ("heat" | "cool" | "fan" | "eco")[];
                    is_heat_pump_compatible: boolean;
                    supports_demand_response: boolean;
                    supports_emergency_heating_mode: boolean;
                };
                software_features: {
                    can_program_climate_schedules: boolean;
                };
            } | {
                main_category: "relay";
            } | {
                main_category: "intercom";
                physical_properties: {
                    has_camera: boolean;
                    has_rfid_reader?: boolean | undefined;
                    has_nfc_reader?: boolean | undefined;
                    has_wiegand_interface?: boolean | undefined;
                };
                software_features: {
                    can_remotely_unlock: boolean;
                    can_program_access_codes: boolean;
                    can_unlock_with_face_recognition?: boolean | undefined;
                    supports_onvif?: boolean | undefined;
                };
            } | {
                main_category: "accessory";
            }))[];
        }>;
    };
    readonly '/api/v1/manufacturers/get': {
        readonly auth: "publishable_key";
        readonly methods: readonly ["GET", "OPTIONS"];
        readonly queryParams: z.ZodObject<{
            manufacturer_id: z.ZodString;
        }, "strip", z.ZodTypeAny, {
            manufacturer_id: string;
        }, {
            manufacturer_id: string;
        }>;
        readonly jsonResponse: z.ZodObject<{
            manufacturer: z.ZodObject<{
                manufacturer_id: z.ZodString;
                display_name: z.ZodString;
                logo: z.ZodOptional<z.ZodObject<{
                    url: z.ZodString;
                    width: z.ZodNumber;
                    height: z.ZodNumber;
                }, "strip", z.ZodTypeAny, {
                    height: number;
                    width: number;
                    url: string;
                }, {
                    height: number;
                    width: number;
                    url: string;
                }>>;
                integration: z.ZodEnum<["stable", "beta", "planned", "unsupported", "inquire"]>;
                integration_support_level: z.ZodEnum<["stable", "beta", "planned", "unsupported", "inquire"]>;
                is_connect_webview_supported: z.ZodBoolean;
                requires_seam_support_to_add_account: z.ZodBoolean;
                device_model_count: z.ZodNumber;
                annotations: z.ZodArray<z.ZodObject<{
                    annotation_code: z.ZodEnum<["subscription_required"]>;
                    message: z.ZodString;
                }, "strip", z.ZodTypeAny, {
                    message: string;
                    annotation_code: "subscription_required";
                }, {
                    message: string;
                    annotation_code: "subscription_required";
                }>, "many">;
                website: z.ZodOptional<z.ZodString>;
                legal_name: z.ZodOptional<z.ZodString>;
                parent_organization: z.ZodOptional<z.ZodString>;
                headquarters: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                countries_of_origin: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                founding_year: z.ZodOptional<z.ZodString>;
                us_customer_support_tel: z.ZodOptional<z.ZodString>;
                us_customer_support_email: z.ZodOptional<z.ZodString>;
                /** @deprecated */
                us_customer_support_contact_url: z.ZodOptional<z.ZodString>;
                seam_api_guide: z.ZodOptional<z.ZodString>;
                description: z.ZodOptional<z.ZodString>;
            }, "strip", z.ZodTypeAny, {
                display_name: string;
                manufacturer_id: string;
                integration: "beta" | "stable" | "planned" | "unsupported" | "inquire";
                integration_support_level: "beta" | "stable" | "planned" | "unsupported" | "inquire";
                is_connect_webview_supported: boolean;
                requires_seam_support_to_add_account: boolean;
                device_model_count: number;
                annotations: {
                    message: string;
                    annotation_code: "subscription_required";
                }[];
                logo?: {
                    height: number;
                    width: number;
                    url: string;
                } | undefined;
                website?: string | undefined;
                legal_name?: string | undefined;
                parent_organization?: string | undefined;
                headquarters?: string[] | undefined;
                countries_of_origin?: string[] | undefined;
                founding_year?: string | undefined;
                us_customer_support_tel?: string | undefined;
                us_customer_support_email?: string | undefined;
                us_customer_support_contact_url?: string | undefined;
                seam_api_guide?: string | undefined;
                description?: string | undefined;
            }, {
                display_name: string;
                manufacturer_id: string;
                integration: "beta" | "stable" | "planned" | "unsupported" | "inquire";
                integration_support_level: "beta" | "stable" | "planned" | "unsupported" | "inquire";
                is_connect_webview_supported: boolean;
                requires_seam_support_to_add_account: boolean;
                device_model_count: number;
                annotations: {
                    message: string;
                    annotation_code: "subscription_required";
                }[];
                logo?: {
                    height: number;
                    width: number;
                    url: string;
                } | undefined;
                website?: string | undefined;
                legal_name?: string | undefined;
                parent_organization?: string | undefined;
                headquarters?: string[] | undefined;
                countries_of_origin?: string[] | undefined;
                founding_year?: string | undefined;
                us_customer_support_tel?: string | undefined;
                us_customer_support_email?: string | undefined;
                us_customer_support_contact_url?: string | undefined;
                seam_api_guide?: string | undefined;
                description?: string | undefined;
            }>;
        }, "strip", z.ZodTypeAny, {
            manufacturer: {
                display_name: string;
                manufacturer_id: string;
                integration: "beta" | "stable" | "planned" | "unsupported" | "inquire";
                integration_support_level: "beta" | "stable" | "planned" | "unsupported" | "inquire";
                is_connect_webview_supported: boolean;
                requires_seam_support_to_add_account: boolean;
                device_model_count: number;
                annotations: {
                    message: string;
                    annotation_code: "subscription_required";
                }[];
                logo?: {
                    height: number;
                    width: number;
                    url: string;
                } | undefined;
                website?: string | undefined;
                legal_name?: string | undefined;
                parent_organization?: string | undefined;
                headquarters?: string[] | undefined;
                countries_of_origin?: string[] | undefined;
                founding_year?: string | undefined;
                us_customer_support_tel?: string | undefined;
                us_customer_support_email?: string | undefined;
                us_customer_support_contact_url?: string | undefined;
                seam_api_guide?: string | undefined;
                description?: string | undefined;
            };
        }, {
            manufacturer: {
                display_name: string;
                manufacturer_id: string;
                integration: "beta" | "stable" | "planned" | "unsupported" | "inquire";
                integration_support_level: "beta" | "stable" | "planned" | "unsupported" | "inquire";
                is_connect_webview_supported: boolean;
                requires_seam_support_to_add_account: boolean;
                device_model_count: number;
                annotations: {
                    message: string;
                    annotation_code: "subscription_required";
                }[];
                logo?: {
                    height: number;
                    width: number;
                    url: string;
                } | undefined;
                website?: string | undefined;
                legal_name?: string | undefined;
                parent_organization?: string | undefined;
                headquarters?: string[] | undefined;
                countries_of_origin?: string[] | undefined;
                founding_year?: string | undefined;
                us_customer_support_tel?: string | undefined;
                us_customer_support_email?: string | undefined;
                us_customer_support_contact_url?: string | undefined;
                seam_api_guide?: string | undefined;
                description?: string | undefined;
            };
        }>;
    };
    readonly '/api/v1/manufacturers/list': {
        readonly auth: "publishable_key";
        readonly methods: readonly ["GET", "OPTIONS"];
        readonly queryParams: z.ZodObject<{
            /** @deprecated */
            integration_status: z.ZodOptional<z.ZodEnum<["stable", "beta", "planned", "unsupported", "inquire"]>>;
            integration_support_levels: z.ZodOptional<z.ZodArray<z.ZodEnum<["stable", "beta", "planned", "unsupported", "inquire"]>, "many">>;
            liqe_query: z.ZodOptional<z.ZodString>;
        }, "strip", z.ZodTypeAny, {
            integration_status?: "beta" | "stable" | "planned" | "unsupported" | "inquire" | undefined;
            integration_support_levels?: ("beta" | "stable" | "planned" | "unsupported" | "inquire")[] | undefined;
            liqe_query?: string | undefined;
        }, {
            integration_status?: "beta" | "stable" | "planned" | "unsupported" | "inquire" | undefined;
            integration_support_levels?: ("beta" | "stable" | "planned" | "unsupported" | "inquire")[] | undefined;
            liqe_query?: string | undefined;
        }>;
        readonly jsonResponse: z.ZodObject<{
            manufacturers: z.ZodArray<z.ZodObject<{
                manufacturer_id: z.ZodString;
                display_name: z.ZodString;
                logo: z.ZodOptional<z.ZodObject<{
                    url: z.ZodString;
                    width: z.ZodNumber;
                    height: z.ZodNumber;
                }, "strip", z.ZodTypeAny, {
                    height: number;
                    width: number;
                    url: string;
                }, {
                    height: number;
                    width: number;
                    url: string;
                }>>;
                integration: z.ZodEnum<["stable", "beta", "planned", "unsupported", "inquire"]>;
                integration_support_level: z.ZodEnum<["stable", "beta", "planned", "unsupported", "inquire"]>;
                is_connect_webview_supported: z.ZodBoolean;
                requires_seam_support_to_add_account: z.ZodBoolean;
                device_model_count: z.ZodNumber;
                annotations: z.ZodArray<z.ZodObject<{
                    annotation_code: z.ZodEnum<["subscription_required"]>;
                    message: z.ZodString;
                }, "strip", z.ZodTypeAny, {
                    message: string;
                    annotation_code: "subscription_required";
                }, {
                    message: string;
                    annotation_code: "subscription_required";
                }>, "many">;
                website: z.ZodOptional<z.ZodString>;
                legal_name: z.ZodOptional<z.ZodString>;
                parent_organization: z.ZodOptional<z.ZodString>;
                headquarters: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                countries_of_origin: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                founding_year: z.ZodOptional<z.ZodString>;
                us_customer_support_tel: z.ZodOptional<z.ZodString>;
                us_customer_support_email: z.ZodOptional<z.ZodString>;
                /** @deprecated */
                us_customer_support_contact_url: z.ZodOptional<z.ZodString>;
                seam_api_guide: z.ZodOptional<z.ZodString>;
                description: z.ZodOptional<z.ZodString>;
            }, "strip", z.ZodTypeAny, {
                display_name: string;
                manufacturer_id: string;
                integration: "beta" | "stable" | "planned" | "unsupported" | "inquire";
                integration_support_level: "beta" | "stable" | "planned" | "unsupported" | "inquire";
                is_connect_webview_supported: boolean;
                requires_seam_support_to_add_account: boolean;
                device_model_count: number;
                annotations: {
                    message: string;
                    annotation_code: "subscription_required";
                }[];
                logo?: {
                    height: number;
                    width: number;
                    url: string;
                } | undefined;
                website?: string | undefined;
                legal_name?: string | undefined;
                parent_organization?: string | undefined;
                headquarters?: string[] | undefined;
                countries_of_origin?: string[] | undefined;
                founding_year?: string | undefined;
                us_customer_support_tel?: string | undefined;
                us_customer_support_email?: string | undefined;
                us_customer_support_contact_url?: string | undefined;
                seam_api_guide?: string | undefined;
                description?: string | undefined;
            }, {
                display_name: string;
                manufacturer_id: string;
                integration: "beta" | "stable" | "planned" | "unsupported" | "inquire";
                integration_support_level: "beta" | "stable" | "planned" | "unsupported" | "inquire";
                is_connect_webview_supported: boolean;
                requires_seam_support_to_add_account: boolean;
                device_model_count: number;
                annotations: {
                    message: string;
                    annotation_code: "subscription_required";
                }[];
                logo?: {
                    height: number;
                    width: number;
                    url: string;
                } | undefined;
                website?: string | undefined;
                legal_name?: string | undefined;
                parent_organization?: string | undefined;
                headquarters?: string[] | undefined;
                countries_of_origin?: string[] | undefined;
                founding_year?: string | undefined;
                us_customer_support_tel?: string | undefined;
                us_customer_support_email?: string | undefined;
                us_customer_support_contact_url?: string | undefined;
                seam_api_guide?: string | undefined;
                description?: string | undefined;
            }>, "many">;
        }, "strip", z.ZodTypeAny, {
            manufacturers: {
                display_name: string;
                manufacturer_id: string;
                integration: "beta" | "stable" | "planned" | "unsupported" | "inquire";
                integration_support_level: "beta" | "stable" | "planned" | "unsupported" | "inquire";
                is_connect_webview_supported: boolean;
                requires_seam_support_to_add_account: boolean;
                device_model_count: number;
                annotations: {
                    message: string;
                    annotation_code: "subscription_required";
                }[];
                logo?: {
                    height: number;
                    width: number;
                    url: string;
                } | undefined;
                website?: string | undefined;
                legal_name?: string | undefined;
                parent_organization?: string | undefined;
                headquarters?: string[] | undefined;
                countries_of_origin?: string[] | undefined;
                founding_year?: string | undefined;
                us_customer_support_tel?: string | undefined;
                us_customer_support_email?: string | undefined;
                us_customer_support_contact_url?: string | undefined;
                seam_api_guide?: string | undefined;
                description?: string | undefined;
            }[];
        }, {
            manufacturers: {
                display_name: string;
                manufacturer_id: string;
                integration: "beta" | "stable" | "planned" | "unsupported" | "inquire";
                integration_support_level: "beta" | "stable" | "planned" | "unsupported" | "inquire";
                is_connect_webview_supported: boolean;
                requires_seam_support_to_add_account: boolean;
                device_model_count: number;
                annotations: {
                    message: string;
                    annotation_code: "subscription_required";
                }[];
                logo?: {
                    height: number;
                    width: number;
                    url: string;
                } | undefined;
                website?: string | undefined;
                legal_name?: string | undefined;
                parent_organization?: string | undefined;
                headquarters?: string[] | undefined;
                countries_of_origin?: string[] | undefined;
                founding_year?: string | undefined;
                us_customer_support_tel?: string | undefined;
                us_customer_support_email?: string | undefined;
                us_customer_support_contact_url?: string | undefined;
                seam_api_guide?: string | undefined;
                description?: string | undefined;
            }[];
        }>;
    };
};
